# Generated by Django 3.1.6 on 2021-02-28 18:07

import _socket
from django.conf import settings
import django.contrib.sites.managers
import django.core.validators
from django.db import migrations, models
import django.db.models.deletion
import django_audit_fields.fields.hostname_modification_field
import django_audit_fields.fields.userfield
import django_audit_fields.fields.uuid_auto_field
import django_audit_fields.models.audit_model_mixin
import django_revision.revision_field
import edc_model.models.fields.duration
import edc_model.models.fields.other_charfield
import edc_model.models.validators.date
import edc_protocol.validators
import edc_utils.date
import edc_visit_tracking.managers
import simple_history.models
import uuid


class Migration(migrations.Migration):

    dependencies = [
        ('sites', '0002_alter_domain_unique'),
        ('mocca_lists', '0004_auto_20210228_2049'),
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ('edc_action_item', '0028_auto_20210203_0706'),
        ('mocca_subject', '0008_auto_20210131_2037'),
    ]

    operations = [
        migrations.CreateModel(
            name='CholInitialReview',
            fields=[
                ('revision', django_revision.revision_field.RevisionField(blank=True, editable=False, help_text='System field. Git repository tag:branch:commit.', max_length=75, null=True, verbose_name='Revision')),
                ('created', models.DateTimeField(blank=True, default=django_audit_fields.models.audit_model_mixin.utcnow)),
                ('modified', models.DateTimeField(blank=True, default=django_audit_fields.models.audit_model_mixin.utcnow)),
                ('user_created', django_audit_fields.fields.userfield.UserField(blank=True, help_text='Updated by admin.save_model', max_length=50, verbose_name='user created')),
                ('user_modified', django_audit_fields.fields.userfield.UserField(blank=True, help_text='Updated by admin.save_model', max_length=50, verbose_name='user modified')),
                ('hostname_created', models.CharField(blank=True, default=_socket.gethostname, help_text='System field. (modified on create only)', max_length=60)),
                ('hostname_modified', django_audit_fields.fields.hostname_modification_field.HostnameModificationField(blank=True, help_text='System field. (modified on every save)', max_length=50)),
                ('device_created', models.CharField(blank=True, max_length=10)),
                ('device_modified', models.CharField(blank=True, max_length=10)),
                ('id', django_audit_fields.fields.uuid_auto_field.UUIDAutoField(blank=True, editable=False, help_text='System auto field. UUID primary key.', primary_key=True, serialize=False)),
                ('report_datetime', models.DateTimeField(default=edc_utils.date.get_utcnow, help_text="If reporting today, use today's date/time, otherwise use the date/time this information was reported.", validators=[edc_protocol.validators.datetime_not_before_study_start, edc_model.models.validators.date.datetime_not_future], verbose_name='Report Date')),
                ('consent_model', models.CharField(editable=False, max_length=50, null=True)),
                ('consent_version', models.CharField(editable=False, max_length=10, null=True)),
                ('crf_status', models.CharField(choices=[('INCOMPLETE', 'Incomplete (some data pending)'), ('COMPLETE', 'Complete')], default='INCOMPLETE', help_text='If some data is still pending, flag this CRF as incomplete', max_length=25, verbose_name='CRF status')),
                ('crf_status_comments', models.TextField(blank=True, help_text='for example, why some data is still pending', null=True, verbose_name='Any comments related to status of this CRF')),
                ('dx_location_other', edc_model.models.fields.other_charfield.OtherCharField(blank=True, max_length=35, null=True, verbose_name='If other, please specify ...')),
                ('dx_ago', edc_model.models.fields.duration.DurationYMDField(blank=True, null=True)),
                ('dx_date', models.DateField(blank=True, help_text='If possible, provide the exact date here instead of estimating above.', null=True, verbose_name='Date patient diagnosed')),
                ('dx_estimated_date', models.DateField(editable=False, help_text='Calculated based on response to `dx_ago`', null=True, verbose_name='Estimated diagnoses date')),
                ('dx_date_estimated', models.CharField(choices=[('Yes', 'Yes'), ('No', 'No')], default='Yes', editable=False, max_length=15, verbose_name='Was the diagnosis date estimated?')),
                ('med_start_ago', edc_model.models.fields.duration.DurationYMDField(blank=True, null=True)),
                ('med_start_estimated_date', models.DateField(editable=False, null=True, verbose_name='Estimated medication start date')),
                ('med_start_date_estimated', models.CharField(choices=[('Yes', 'Yes'), ('No', 'No')], default='Yes', editable=False, max_length=15, verbose_name='Was the medication start date estimated?')),
                ('managed_by', models.CharField(choices=[('drugs', 'Oral drugs'), ('diet_lifestyle', 'Diet and lifestyle alone')], default='N/A', max_length=25, verbose_name="How is the patient's cholesterol managed?")),
                ('chol_performed', models.CharField(choices=[('Yes', 'Yes'), ('No', 'No')], max_length=15, verbose_name='Has the patient had their cholesterol measured in the last few months?')),
                ('dx_location', models.ForeignKey(on_delete=django.db.models.deletion.PROTECT, to='mocca_lists.diagnosislocations', verbose_name='Where was the diagnosis made?')),
                ('site', models.ForeignKey(editable=False, null=True, on_delete=django.db.models.deletion.PROTECT, related_name='+', to='sites.site')),
                ('subject_visit', models.OneToOneField(on_delete=django.db.models.deletion.PROTECT, to='mocca_subject.subjectvisit')),
            ],
            options={
                'verbose_name': 'High Cholesterol Initial Review',
                'verbose_name_plural': 'High Cholesterol Initial Reviews',
                'ordering': ('-modified', '-created'),
                'get_latest_by': 'modified',
                'abstract': False,
                'default_permissions': ('add', 'change', 'delete', 'view', 'export', 'import'),
            },
            managers=[
                ('on_site', django.contrib.sites.managers.CurrentSiteManager()),
                ('objects', edc_visit_tracking.managers.CrfModelManager()),
            ],
        ),
        migrations.CreateModel(
            name='CholMedicationAdherence',
            fields=[
                ('revision', django_revision.revision_field.RevisionField(blank=True, editable=False, help_text='System field. Git repository tag:branch:commit.', max_length=75, null=True, verbose_name='Revision')),
                ('created', models.DateTimeField(blank=True, default=django_audit_fields.models.audit_model_mixin.utcnow)),
                ('modified', models.DateTimeField(blank=True, default=django_audit_fields.models.audit_model_mixin.utcnow)),
                ('user_created', django_audit_fields.fields.userfield.UserField(blank=True, help_text='Updated by admin.save_model', max_length=50, verbose_name='user created')),
                ('user_modified', django_audit_fields.fields.userfield.UserField(blank=True, help_text='Updated by admin.save_model', max_length=50, verbose_name='user modified')),
                ('hostname_created', models.CharField(blank=True, default=_socket.gethostname, help_text='System field. (modified on create only)', max_length=60)),
                ('hostname_modified', django_audit_fields.fields.hostname_modification_field.HostnameModificationField(blank=True, help_text='System field. (modified on every save)', max_length=50)),
                ('device_created', models.CharField(blank=True, max_length=10)),
                ('device_modified', models.CharField(blank=True, max_length=10)),
                ('id', django_audit_fields.fields.uuid_auto_field.UUIDAutoField(blank=True, editable=False, help_text='System auto field. UUID primary key.', primary_key=True, serialize=False)),
                ('report_datetime', models.DateTimeField(default=edc_utils.date.get_utcnow, help_text="If reporting today, use today's date/time, otherwise use the date/time this information was reported.", validators=[edc_protocol.validators.datetime_not_before_study_start, edc_model.models.validators.date.datetime_not_future], verbose_name='Report Date')),
                ('consent_model', models.CharField(editable=False, max_length=50, null=True)),
                ('consent_version', models.CharField(editable=False, max_length=10, null=True)),
                ('crf_status', models.CharField(choices=[('INCOMPLETE', 'Incomplete (some data pending)'), ('COMPLETE', 'Complete')], default='INCOMPLETE', help_text='If some data is still pending, flag this CRF as incomplete', max_length=25, verbose_name='CRF status')),
                ('crf_status_comments', models.TextField(blank=True, help_text='for example, why some data is still pending', null=True, verbose_name='Any comments related to status of this CRF')),
                ('visual_score_slider', models.CharField(help_text='%', max_length=3, verbose_name='Visual score')),
                ('visual_score_confirmed', models.IntegerField(help_text='%', validators=[django.core.validators.MinValueValidator(0), django.core.validators.MaxValueValidator(100)], verbose_name="<B><font color='orange'>Interviewer</font></B>: please confirm the score indicated from above.")),
                ('last_missed_pill', models.CharField(choices=[('today', 'today'), ('yesterday', 'yesterday'), ('earlier_this_week', 'earlier this week'), ('last_week', 'last week'), ('lt_month_ago', 'less than a month ago'), ('gt_month_ago', 'more than a month ago'), ('NEVER', 'have never missed taking my study pills')], max_length=25, verbose_name='When was the last time you missed your study pill?')),
                ('pill_count', models.IntegerField(verbose_name='Number of pills left in the bottle')),
                ('other_missed_pill_reason', edc_model.models.fields.other_charfield.OtherCharField(blank=True, max_length=35, null=True, verbose_name='If other, please specify ...')),
                ('missed_pill_reason', models.ManyToManyField(blank=True, to='mocca_lists.NonAdherenceReasons', verbose_name='Reasons for missing study pills')),
                ('site', models.ForeignKey(editable=False, null=True, on_delete=django.db.models.deletion.PROTECT, related_name='+', to='sites.site')),
                ('subject_visit', models.OneToOneField(on_delete=django.db.models.deletion.PROTECT, to='mocca_subject.subjectvisit')),
            ],
            options={
                'verbose_name': 'Cholesterol Medication Adherence',
                'verbose_name_plural': 'Cholesterol Medication Adherence',
                'ordering': ('-modified', '-created'),
                'get_latest_by': 'modified',
                'abstract': False,
                'default_permissions': ('add', 'change', 'delete', 'view', 'export', 'import'),
            },
            managers=[
                ('on_site', django.contrib.sites.managers.CurrentSiteManager()),
                ('objects', edc_visit_tracking.managers.CrfModelManager()),
            ],
        ),
        migrations.CreateModel(
            name='CholReview',
            fields=[
                ('revision', django_revision.revision_field.RevisionField(blank=True, editable=False, help_text='System field. Git repository tag:branch:commit.', max_length=75, null=True, verbose_name='Revision')),
                ('created', models.DateTimeField(blank=True, default=django_audit_fields.models.audit_model_mixin.utcnow)),
                ('modified', models.DateTimeField(blank=True, default=django_audit_fields.models.audit_model_mixin.utcnow)),
                ('user_created', django_audit_fields.fields.userfield.UserField(blank=True, help_text='Updated by admin.save_model', max_length=50, verbose_name='user created')),
                ('user_modified', django_audit_fields.fields.userfield.UserField(blank=True, help_text='Updated by admin.save_model', max_length=50, verbose_name='user modified')),
                ('hostname_created', models.CharField(blank=True, default=_socket.gethostname, help_text='System field. (modified on create only)', max_length=60)),
                ('hostname_modified', django_audit_fields.fields.hostname_modification_field.HostnameModificationField(blank=True, help_text='System field. (modified on every save)', max_length=50)),
                ('device_created', models.CharField(blank=True, max_length=10)),
                ('device_modified', models.CharField(blank=True, max_length=10)),
                ('id', django_audit_fields.fields.uuid_auto_field.UUIDAutoField(blank=True, editable=False, help_text='System auto field. UUID primary key.', primary_key=True, serialize=False)),
                ('report_datetime', models.DateTimeField(default=edc_utils.date.get_utcnow, help_text="If reporting today, use today's date/time, otherwise use the date/time this information was reported.", validators=[edc_protocol.validators.datetime_not_before_study_start, edc_model.models.validators.date.datetime_not_future], verbose_name='Report Date')),
                ('consent_model', models.CharField(editable=False, max_length=50, null=True)),
                ('consent_version', models.CharField(editable=False, max_length=10, null=True)),
                ('crf_status', models.CharField(choices=[('INCOMPLETE', 'Incomplete (some data pending)'), ('COMPLETE', 'Complete')], default='INCOMPLETE', help_text='If some data is still pending, flag this CRF as incomplete', max_length=25, verbose_name='CRF status')),
                ('crf_status_comments', models.TextField(blank=True, help_text='for example, why some data is still pending', null=True, verbose_name='Any comments related to status of this CRF')),
                ('care_delivery', models.CharField(choices=[('Yes', 'Yes'), ('No', 'No'), ('N/A', 'Not applicable')], default='N/A', help_text='Select `not applicable` if site was not selected for integrated care.', max_length=25, verbose_name='Was care for this `condition` delivered in an integrated care clinic today?')),
                ('care_delivery_other', models.TextField(blank=True, null=True, verbose_name='If no, please explain')),
                ('test_date', models.DateField(blank=True, editable=False, help_text='QUESTION_RETIRED', null=True, verbose_name='Date tested for High Cholesterol')),
                ('dx', models.CharField(choices=[('Yes', 'Yes'), ('No', 'No'), ('N/A', 'Not applicable')], default='N/A', editable=False, help_text='QUESTION_RETIRED', max_length=15, verbose_name='Has the patient been diagnosed with High Cholesterol?')),
                ('managed_by', models.CharField(choices=[('insulin', 'Insulin injections'), ('drugs', 'Oral drugs'), ('diet_lifestyle', 'Diet and lifestyle alone')], default='N/A', max_length=25, verbose_name="How will the patient's High Cholesterol be managed going forward?")),
                ('care_start_date', models.DateField(editable=False, help_text='QUESTION_RETIRED', null=True, verbose_name='Date clinical management started')),
                ('site', models.ForeignKey(editable=False, null=True, on_delete=django.db.models.deletion.PROTECT, related_name='+', to='sites.site')),
                ('subject_visit', models.OneToOneField(on_delete=django.db.models.deletion.PROTECT, to='mocca_subject.subjectvisit')),
            ],
            options={
                'verbose_name': 'High Cholesterol Review',
                'verbose_name_plural': 'High Cholesterol Review',
                'ordering': ('-modified', '-created'),
                'get_latest_by': 'modified',
                'abstract': False,
                'default_permissions': ('add', 'change', 'delete', 'view', 'export', 'import'),
            },
            managers=[
                ('on_site', django.contrib.sites.managers.CurrentSiteManager()),
                ('objects', edc_visit_tracking.managers.CrfModelManager()),
            ],
        ),
        migrations.CreateModel(
            name='DrugRefillChol',
            fields=[
                ('revision', django_revision.revision_field.RevisionField(blank=True, editable=False, help_text='System field. Git repository tag:branch:commit.', max_length=75, null=True, verbose_name='Revision')),
                ('created', models.DateTimeField(blank=True, default=django_audit_fields.models.audit_model_mixin.utcnow)),
                ('modified', models.DateTimeField(blank=True, default=django_audit_fields.models.audit_model_mixin.utcnow)),
                ('user_created', django_audit_fields.fields.userfield.UserField(blank=True, help_text='Updated by admin.save_model', max_length=50, verbose_name='user created')),
                ('user_modified', django_audit_fields.fields.userfield.UserField(blank=True, help_text='Updated by admin.save_model', max_length=50, verbose_name='user modified')),
                ('hostname_created', models.CharField(blank=True, default=_socket.gethostname, help_text='System field. (modified on create only)', max_length=60)),
                ('hostname_modified', django_audit_fields.fields.hostname_modification_field.HostnameModificationField(blank=True, help_text='System field. (modified on every save)', max_length=50)),
                ('device_created', models.CharField(blank=True, max_length=10)),
                ('device_modified', models.CharField(blank=True, max_length=10)),
                ('id', django_audit_fields.fields.uuid_auto_field.UUIDAutoField(blank=True, editable=False, help_text='System auto field. UUID primary key.', primary_key=True, serialize=False)),
                ('report_datetime', models.DateTimeField(default=edc_utils.date.get_utcnow, help_text="If reporting today, use today's date/time, otherwise use the date/time this information was reported.", validators=[edc_protocol.validators.datetime_not_before_study_start, edc_model.models.validators.date.datetime_not_future], verbose_name='Report Date')),
                ('consent_model', models.CharField(editable=False, max_length=50, null=True)),
                ('consent_version', models.CharField(editable=False, max_length=10, null=True)),
                ('crf_status', models.CharField(choices=[('INCOMPLETE', 'Incomplete (some data pending)'), ('COMPLETE', 'Complete')], default='INCOMPLETE', help_text='If some data is still pending, flag this CRF as incomplete', max_length=25, verbose_name='CRF status')),
                ('crf_status_comments', models.TextField(blank=True, help_text='for example, why some data is still pending', null=True, verbose_name='Any comments related to status of this CRF')),
                ('rx_other', models.CharField(blank=True, max_length=150, null=True, verbose_name='If other, please specify ...')),
                ('rx_modified', models.CharField(choices=[('Yes', 'Yes'), ('No', 'No')], max_length=25, verbose_name='Was the patient’s prescription changed at this visit compared with their prescription at the previous visit?')),
                ('modifications_other', models.CharField(blank=True, max_length=150, null=True, verbose_name='If other, please specify ...')),
                ('modifications_reason_other', models.CharField(blank=True, max_length=150, null=True, verbose_name='If other, please specify ...')),
                ('return_in_days', models.IntegerField(verbose_name='In how many days has the patient been asked to return to clinic for a drug refill?')),
                ('modifications', models.ManyToManyField(blank=True, to='mocca_lists.RxModifications', verbose_name='Which changes occurred?')),
                ('modifications_reason', models.ManyToManyField(blank=True, to='mocca_lists.RxModificationReasons', verbose_name='Why did the patient’s previous prescription change?')),
                ('rx', models.ManyToManyField(to='mocca_lists.CholTreatments', verbose_name='Which medicine did the patient receive today?')),
                ('site', models.ForeignKey(editable=False, null=True, on_delete=django.db.models.deletion.PROTECT, related_name='+', to='sites.site')),
                ('subject_visit', models.OneToOneField(on_delete=django.db.models.deletion.PROTECT, to='mocca_subject.subjectvisit')),
            ],
            options={
                'verbose_name': 'Drug Refill: Cholesterol',
                'verbose_name_plural': 'Drug Refills: Cholesterol',
                'ordering': ('-modified', '-created'),
                'get_latest_by': 'modified',
                'abstract': False,
                'default_permissions': ('add', 'change', 'delete', 'view', 'export', 'import'),
            },
            managers=[
                ('on_site', django.contrib.sites.managers.CurrentSiteManager()),
                ('objects', edc_visit_tracking.managers.CrfModelManager()),
            ],
        ),
        migrations.CreateModel(
            name='DrugSupplyChol',
            fields=[
                ('revision', django_revision.revision_field.RevisionField(blank=True, editable=False, help_text='System field. Git repository tag:branch:commit.', max_length=75, null=True, verbose_name='Revision')),
                ('created', models.DateTimeField(blank=True, default=django_audit_fields.models.audit_model_mixin.utcnow)),
                ('modified', models.DateTimeField(blank=True, default=django_audit_fields.models.audit_model_mixin.utcnow)),
                ('user_created', django_audit_fields.fields.userfield.UserField(blank=True, help_text='Updated by admin.save_model', max_length=50, verbose_name='user created')),
                ('user_modified', django_audit_fields.fields.userfield.UserField(blank=True, help_text='Updated by admin.save_model', max_length=50, verbose_name='user modified')),
                ('hostname_created', models.CharField(blank=True, default=_socket.gethostname, help_text='System field. (modified on create only)', max_length=60)),
                ('hostname_modified', django_audit_fields.fields.hostname_modification_field.HostnameModificationField(blank=True, help_text='System field. (modified on every save)', max_length=50)),
                ('device_created', models.CharField(blank=True, max_length=10)),
                ('device_modified', models.CharField(blank=True, max_length=10)),
                ('id', django_audit_fields.fields.uuid_auto_field.UUIDAutoField(blank=True, editable=False, help_text='System auto field. UUID primary key.', primary_key=True, serialize=False)),
                ('drug', models.ForeignKey(on_delete=django.db.models.deletion.PROTECT, to='mocca_lists.choltreatments')),
                ('drug_refill', models.ForeignKey(on_delete=django.db.models.deletion.PROTECT, to='mocca_subject.drugrefillchol')),
            ],
            options={
                'verbose_name': 'Drug Supply: Hypertension',
                'verbose_name_plural': 'Drug Supply: Hypertension',
                'ordering': ('-modified', '-created'),
                'get_latest_by': 'modified',
                'abstract': False,
                'default_permissions': ('add', 'change', 'delete', 'view', 'export', 'import'),
            },
        ),
        migrations.CreateModel(
            name='HistoricalCholInitialReview',
            fields=[
                ('revision', django_revision.revision_field.RevisionField(blank=True, editable=False, help_text='System field. Git repository tag:branch:commit.', max_length=75, null=True, verbose_name='Revision')),
                ('created', models.DateTimeField(blank=True, default=django_audit_fields.models.audit_model_mixin.utcnow)),
                ('modified', models.DateTimeField(blank=True, default=django_audit_fields.models.audit_model_mixin.utcnow)),
                ('user_created', django_audit_fields.fields.userfield.UserField(blank=True, help_text='Updated by admin.save_model', max_length=50, verbose_name='user created')),
                ('user_modified', django_audit_fields.fields.userfield.UserField(blank=True, help_text='Updated by admin.save_model', max_length=50, verbose_name='user modified')),
                ('hostname_created', models.CharField(blank=True, default=_socket.gethostname, help_text='System field. (modified on create only)', max_length=60)),
                ('hostname_modified', django_audit_fields.fields.hostname_modification_field.HostnameModificationField(blank=True, help_text='System field. (modified on every save)', max_length=50)),
                ('device_created', models.CharField(blank=True, max_length=10)),
                ('device_modified', models.CharField(blank=True, max_length=10)),
                ('id', django_audit_fields.fields.uuid_auto_field.UUIDAutoField(blank=True, db_index=True, editable=False, help_text='System auto field. UUID primary key.')),
                ('report_datetime', models.DateTimeField(default=edc_utils.date.get_utcnow, help_text="If reporting today, use today's date/time, otherwise use the date/time this information was reported.", validators=[edc_protocol.validators.datetime_not_before_study_start, edc_model.models.validators.date.datetime_not_future], verbose_name='Report Date')),
                ('consent_model', models.CharField(editable=False, max_length=50, null=True)),
                ('consent_version', models.CharField(editable=False, max_length=10, null=True)),
                ('crf_status', models.CharField(choices=[('INCOMPLETE', 'Incomplete (some data pending)'), ('COMPLETE', 'Complete')], default='INCOMPLETE', help_text='If some data is still pending, flag this CRF as incomplete', max_length=25, verbose_name='CRF status')),
                ('crf_status_comments', models.TextField(blank=True, help_text='for example, why some data is still pending', null=True, verbose_name='Any comments related to status of this CRF')),
                ('history_id', models.UUIDField(default=uuid.uuid4, editable=False, primary_key=True, serialize=False)),
                ('dx_location_other', edc_model.models.fields.other_charfield.OtherCharField(blank=True, max_length=35, null=True, verbose_name='If other, please specify ...')),
                ('dx_ago', edc_model.models.fields.duration.DurationYMDField(blank=True, null=True)),
                ('dx_date', models.DateField(blank=True, help_text='If possible, provide the exact date here instead of estimating above.', null=True, verbose_name='Date patient diagnosed')),
                ('dx_estimated_date', models.DateField(editable=False, help_text='Calculated based on response to `dx_ago`', null=True, verbose_name='Estimated diagnoses date')),
                ('dx_date_estimated', models.CharField(choices=[('Yes', 'Yes'), ('No', 'No')], default='Yes', editable=False, max_length=15, verbose_name='Was the diagnosis date estimated?')),
                ('med_start_ago', edc_model.models.fields.duration.DurationYMDField(blank=True, null=True)),
                ('med_start_estimated_date', models.DateField(editable=False, null=True, verbose_name='Estimated medication start date')),
                ('med_start_date_estimated', models.CharField(choices=[('Yes', 'Yes'), ('No', 'No')], default='Yes', editable=False, max_length=15, verbose_name='Was the medication start date estimated?')),
                ('managed_by', models.CharField(choices=[('drugs', 'Oral drugs'), ('diet_lifestyle', 'Diet and lifestyle alone')], default='N/A', max_length=25, verbose_name="How is the patient's cholesterol managed?")),
                ('chol_performed', models.CharField(choices=[('Yes', 'Yes'), ('No', 'No')], max_length=15, verbose_name='Has the patient had their cholesterol measured in the last few months?')),
                ('history_date', models.DateTimeField()),
                ('history_change_reason', models.CharField(max_length=100, null=True)),
                ('history_type', models.CharField(choices=[('+', 'Created'), ('~', 'Changed'), ('-', 'Deleted')], max_length=1)),
                ('dx_location', models.ForeignKey(blank=True, db_constraint=False, null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='+', to='mocca_lists.diagnosislocations', verbose_name='Where was the diagnosis made?')),
                ('history_user', models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='+', to=settings.AUTH_USER_MODEL)),
                ('site', models.ForeignKey(blank=True, db_constraint=False, editable=False, null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='+', to='sites.site')),
                ('subject_visit', models.ForeignKey(blank=True, db_constraint=False, null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='+', to='mocca_subject.subjectvisit')),
            ],
            options={
                'verbose_name': 'historical High Cholesterol Initial Review',
                'ordering': ('-history_date', '-history_id'),
                'get_latest_by': 'history_date',
            },
            bases=(simple_history.models.HistoricalChanges, models.Model),
        ),
        migrations.CreateModel(
            name='HistoricalCholMedicationAdherence',
            fields=[
                ('revision', django_revision.revision_field.RevisionField(blank=True, editable=False, help_text='System field. Git repository tag:branch:commit.', max_length=75, null=True, verbose_name='Revision')),
                ('created', models.DateTimeField(blank=True, default=django_audit_fields.models.audit_model_mixin.utcnow)),
                ('modified', models.DateTimeField(blank=True, default=django_audit_fields.models.audit_model_mixin.utcnow)),
                ('user_created', django_audit_fields.fields.userfield.UserField(blank=True, help_text='Updated by admin.save_model', max_length=50, verbose_name='user created')),
                ('user_modified', django_audit_fields.fields.userfield.UserField(blank=True, help_text='Updated by admin.save_model', max_length=50, verbose_name='user modified')),
                ('hostname_created', models.CharField(blank=True, default=_socket.gethostname, help_text='System field. (modified on create only)', max_length=60)),
                ('hostname_modified', django_audit_fields.fields.hostname_modification_field.HostnameModificationField(blank=True, help_text='System field. (modified on every save)', max_length=50)),
                ('device_created', models.CharField(blank=True, max_length=10)),
                ('device_modified', models.CharField(blank=True, max_length=10)),
                ('id', django_audit_fields.fields.uuid_auto_field.UUIDAutoField(blank=True, db_index=True, editable=False, help_text='System auto field. UUID primary key.')),
                ('report_datetime', models.DateTimeField(default=edc_utils.date.get_utcnow, help_text="If reporting today, use today's date/time, otherwise use the date/time this information was reported.", validators=[edc_protocol.validators.datetime_not_before_study_start, edc_model.models.validators.date.datetime_not_future], verbose_name='Report Date')),
                ('consent_model', models.CharField(editable=False, max_length=50, null=True)),
                ('consent_version', models.CharField(editable=False, max_length=10, null=True)),
                ('crf_status', models.CharField(choices=[('INCOMPLETE', 'Incomplete (some data pending)'), ('COMPLETE', 'Complete')], default='INCOMPLETE', help_text='If some data is still pending, flag this CRF as incomplete', max_length=25, verbose_name='CRF status')),
                ('crf_status_comments', models.TextField(blank=True, help_text='for example, why some data is still pending', null=True, verbose_name='Any comments related to status of this CRF')),
                ('history_id', models.UUIDField(default=uuid.uuid4, editable=False, primary_key=True, serialize=False)),
                ('visual_score_slider', models.CharField(help_text='%', max_length=3, verbose_name='Visual score')),
                ('visual_score_confirmed', models.IntegerField(help_text='%', validators=[django.core.validators.MinValueValidator(0), django.core.validators.MaxValueValidator(100)], verbose_name="<B><font color='orange'>Interviewer</font></B>: please confirm the score indicated from above.")),
                ('last_missed_pill', models.CharField(choices=[('today', 'today'), ('yesterday', 'yesterday'), ('earlier_this_week', 'earlier this week'), ('last_week', 'last week'), ('lt_month_ago', 'less than a month ago'), ('gt_month_ago', 'more than a month ago'), ('NEVER', 'have never missed taking my study pills')], max_length=25, verbose_name='When was the last time you missed your study pill?')),
                ('pill_count', models.IntegerField(verbose_name='Number of pills left in the bottle')),
                ('other_missed_pill_reason', edc_model.models.fields.other_charfield.OtherCharField(blank=True, max_length=35, null=True, verbose_name='If other, please specify ...')),
                ('history_date', models.DateTimeField()),
                ('history_change_reason', models.CharField(max_length=100, null=True)),
                ('history_type', models.CharField(choices=[('+', 'Created'), ('~', 'Changed'), ('-', 'Deleted')], max_length=1)),
                ('history_user', models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='+', to=settings.AUTH_USER_MODEL)),
                ('site', models.ForeignKey(blank=True, db_constraint=False, editable=False, null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='+', to='sites.site')),
                ('subject_visit', models.ForeignKey(blank=True, db_constraint=False, null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='+', to='mocca_subject.subjectvisit')),
            ],
            options={
                'verbose_name': 'historical Cholesterol Medication Adherence',
                'ordering': ('-history_date', '-history_id'),
                'get_latest_by': 'history_date',
            },
            bases=(simple_history.models.HistoricalChanges, models.Model),
        ),
        migrations.CreateModel(
            name='HistoricalCholReview',
            fields=[
                ('revision', django_revision.revision_field.RevisionField(blank=True, editable=False, help_text='System field. Git repository tag:branch:commit.', max_length=75, null=True, verbose_name='Revision')),
                ('created', models.DateTimeField(blank=True, default=django_audit_fields.models.audit_model_mixin.utcnow)),
                ('modified', models.DateTimeField(blank=True, default=django_audit_fields.models.audit_model_mixin.utcnow)),
                ('user_created', django_audit_fields.fields.userfield.UserField(blank=True, help_text='Updated by admin.save_model', max_length=50, verbose_name='user created')),
                ('user_modified', django_audit_fields.fields.userfield.UserField(blank=True, help_text='Updated by admin.save_model', max_length=50, verbose_name='user modified')),
                ('hostname_created', models.CharField(blank=True, default=_socket.gethostname, help_text='System field. (modified on create only)', max_length=60)),
                ('hostname_modified', django_audit_fields.fields.hostname_modification_field.HostnameModificationField(blank=True, help_text='System field. (modified on every save)', max_length=50)),
                ('device_created', models.CharField(blank=True, max_length=10)),
                ('device_modified', models.CharField(blank=True, max_length=10)),
                ('id', django_audit_fields.fields.uuid_auto_field.UUIDAutoField(blank=True, db_index=True, editable=False, help_text='System auto field. UUID primary key.')),
                ('report_datetime', models.DateTimeField(default=edc_utils.date.get_utcnow, help_text="If reporting today, use today's date/time, otherwise use the date/time this information was reported.", validators=[edc_protocol.validators.datetime_not_before_study_start, edc_model.models.validators.date.datetime_not_future], verbose_name='Report Date')),
                ('consent_model', models.CharField(editable=False, max_length=50, null=True)),
                ('consent_version', models.CharField(editable=False, max_length=10, null=True)),
                ('crf_status', models.CharField(choices=[('INCOMPLETE', 'Incomplete (some data pending)'), ('COMPLETE', 'Complete')], default='INCOMPLETE', help_text='If some data is still pending, flag this CRF as incomplete', max_length=25, verbose_name='CRF status')),
                ('crf_status_comments', models.TextField(blank=True, help_text='for example, why some data is still pending', null=True, verbose_name='Any comments related to status of this CRF')),
                ('history_id', models.UUIDField(default=uuid.uuid4, editable=False, primary_key=True, serialize=False)),
                ('care_delivery', models.CharField(choices=[('Yes', 'Yes'), ('No', 'No'), ('N/A', 'Not applicable')], default='N/A', help_text='Select `not applicable` if site was not selected for integrated care.', max_length=25, verbose_name='Was care for this `condition` delivered in an integrated care clinic today?')),
                ('care_delivery_other', models.TextField(blank=True, null=True, verbose_name='If no, please explain')),
                ('test_date', models.DateField(blank=True, editable=False, help_text='QUESTION_RETIRED', null=True, verbose_name='Date tested for High Cholesterol')),
                ('dx', models.CharField(choices=[('Yes', 'Yes'), ('No', 'No'), ('N/A', 'Not applicable')], default='N/A', editable=False, help_text='QUESTION_RETIRED', max_length=15, verbose_name='Has the patient been diagnosed with High Cholesterol?')),
                ('managed_by', models.CharField(choices=[('insulin', 'Insulin injections'), ('drugs', 'Oral drugs'), ('diet_lifestyle', 'Diet and lifestyle alone')], default='N/A', max_length=25, verbose_name="How will the patient's High Cholesterol be managed going forward?")),
                ('care_start_date', models.DateField(editable=False, help_text='QUESTION_RETIRED', null=True, verbose_name='Date clinical management started')),
                ('history_date', models.DateTimeField()),
                ('history_change_reason', models.CharField(max_length=100, null=True)),
                ('history_type', models.CharField(choices=[('+', 'Created'), ('~', 'Changed'), ('-', 'Deleted')], max_length=1)),
                ('history_user', models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='+', to=settings.AUTH_USER_MODEL)),
                ('site', models.ForeignKey(blank=True, db_constraint=False, editable=False, null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='+', to='sites.site')),
                ('subject_visit', models.ForeignKey(blank=True, db_constraint=False, null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='+', to='mocca_subject.subjectvisit')),
            ],
            options={
                'verbose_name': 'historical High Cholesterol Review',
                'ordering': ('-history_date', '-history_id'),
                'get_latest_by': 'history_date',
            },
            bases=(simple_history.models.HistoricalChanges, models.Model),
        ),
        migrations.CreateModel(
            name='HistoricalDrugRefillChol',
            fields=[
                ('revision', django_revision.revision_field.RevisionField(blank=True, editable=False, help_text='System field. Git repository tag:branch:commit.', max_length=75, null=True, verbose_name='Revision')),
                ('created', models.DateTimeField(blank=True, default=django_audit_fields.models.audit_model_mixin.utcnow)),
                ('modified', models.DateTimeField(blank=True, default=django_audit_fields.models.audit_model_mixin.utcnow)),
                ('user_created', django_audit_fields.fields.userfield.UserField(blank=True, help_text='Updated by admin.save_model', max_length=50, verbose_name='user created')),
                ('user_modified', django_audit_fields.fields.userfield.UserField(blank=True, help_text='Updated by admin.save_model', max_length=50, verbose_name='user modified')),
                ('hostname_created', models.CharField(blank=True, default=_socket.gethostname, help_text='System field. (modified on create only)', max_length=60)),
                ('hostname_modified', django_audit_fields.fields.hostname_modification_field.HostnameModificationField(blank=True, help_text='System field. (modified on every save)', max_length=50)),
                ('device_created', models.CharField(blank=True, max_length=10)),
                ('device_modified', models.CharField(blank=True, max_length=10)),
                ('id', django_audit_fields.fields.uuid_auto_field.UUIDAutoField(blank=True, db_index=True, editable=False, help_text='System auto field. UUID primary key.')),
                ('report_datetime', models.DateTimeField(default=edc_utils.date.get_utcnow, help_text="If reporting today, use today's date/time, otherwise use the date/time this information was reported.", validators=[edc_protocol.validators.datetime_not_before_study_start, edc_model.models.validators.date.datetime_not_future], verbose_name='Report Date')),
                ('consent_model', models.CharField(editable=False, max_length=50, null=True)),
                ('consent_version', models.CharField(editable=False, max_length=10, null=True)),
                ('crf_status', models.CharField(choices=[('INCOMPLETE', 'Incomplete (some data pending)'), ('COMPLETE', 'Complete')], default='INCOMPLETE', help_text='If some data is still pending, flag this CRF as incomplete', max_length=25, verbose_name='CRF status')),
                ('crf_status_comments', models.TextField(blank=True, help_text='for example, why some data is still pending', null=True, verbose_name='Any comments related to status of this CRF')),
                ('history_id', models.UUIDField(default=uuid.uuid4, editable=False, primary_key=True, serialize=False)),
                ('rx_other', models.CharField(blank=True, max_length=150, null=True, verbose_name='If other, please specify ...')),
                ('rx_modified', models.CharField(choices=[('Yes', 'Yes'), ('No', 'No')], max_length=25, verbose_name='Was the patient’s prescription changed at this visit compared with their prescription at the previous visit?')),
                ('modifications_other', models.CharField(blank=True, max_length=150, null=True, verbose_name='If other, please specify ...')),
                ('modifications_reason_other', models.CharField(blank=True, max_length=150, null=True, verbose_name='If other, please specify ...')),
                ('return_in_days', models.IntegerField(verbose_name='In how many days has the patient been asked to return to clinic for a drug refill?')),
                ('history_date', models.DateTimeField()),
                ('history_change_reason', models.CharField(max_length=100, null=True)),
                ('history_type', models.CharField(choices=[('+', 'Created'), ('~', 'Changed'), ('-', 'Deleted')], max_length=1)),
                ('history_user', models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='+', to=settings.AUTH_USER_MODEL)),
                ('site', models.ForeignKey(blank=True, db_constraint=False, editable=False, null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='+', to='sites.site')),
                ('subject_visit', models.ForeignKey(blank=True, db_constraint=False, null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='+', to='mocca_subject.subjectvisit')),
            ],
            options={
                'verbose_name': 'historical Drug Refill: Cholesterol',
                'ordering': ('-history_date', '-history_id'),
                'get_latest_by': 'history_date',
            },
            bases=(simple_history.models.HistoricalChanges, models.Model),
        ),
        migrations.RemoveField(
            model_name='healtheconomicsrevised',
            name='rx_dm_paid_month',
        ),
        migrations.RemoveField(
            model_name='healtheconomicsrevised',
            name='rx_dm_paid_today',
        ),
        migrations.RemoveField(
            model_name='healtheconomicsrevised',
            name='rx_hiv_paid_month',
        ),
        migrations.RemoveField(
            model_name='healtheconomicsrevised',
            name='rx_hiv_paid_today',
        ),
        migrations.RemoveField(
            model_name='healtheconomicsrevised',
            name='rx_htn_paid_month',
        ),
        migrations.RemoveField(
            model_name='healtheconomicsrevised',
            name='rx_htn_paid_today',
        ),
        migrations.RemoveField(
            model_name='healtheconomicsrevised',
            name='rx_other_paid_month',
        ),
        migrations.RemoveField(
            model_name='healtheconomicsrevised',
            name='rx_other_paid_today',
        ),
        migrations.RemoveField(
            model_name='healtheconomicsrevised',
            name='site',
        ),
        migrations.RemoveField(
            model_name='healtheconomicsrevised',
            name='subject_visit',
        ),
        migrations.RemoveField(
            model_name='healtheconomicsrevised',
            name='transport',
        ),
        migrations.RemoveField(
            model_name='historicalhealtheconomics',
            name='history_user',
        ),
        migrations.RemoveField(
            model_name='historicalhealtheconomics',
            name='site',
        ),
        migrations.RemoveField(
            model_name='historicalhealtheconomics',
            name='subject_visit',
        ),
        migrations.RemoveField(
            model_name='historicalhealtheconomicsrevised',
            name='history_user',
        ),
        migrations.RemoveField(
            model_name='historicalhealtheconomicsrevised',
            name='site',
        ),
        migrations.RemoveField(
            model_name='historicalhealtheconomicsrevised',
            name='subject_visit',
        ),
        migrations.RemoveField(
            model_name='historicalreasonforvisit',
            name='history_user',
        ),
        migrations.RemoveField(
            model_name='historicalreasonforvisit',
            name='site',
        ),
        migrations.RemoveField(
            model_name='historicalreasonforvisit',
            name='subject_visit',
        ),
        migrations.RemoveField(
            model_name='reasonforvisit',
            name='clinic_services',
        ),
        migrations.RemoveField(
            model_name='reasonforvisit',
            name='site',
        ),
        migrations.RemoveField(
            model_name='reasonforvisit',
            name='subject_visit',
        ),
        migrations.AlterModelOptions(
            name='historicalpatienthealth',
            options={'get_latest_by': 'history_date', 'ordering': ('-history_date', '-history_id'), 'verbose_name': 'historical Patient Health Questionnaire-9 (PHQ-9)'},
        ),
        migrations.AlterModelOptions(
            name='patienthealth',
            options={'default_permissions': ('add', 'change', 'delete', 'view', 'export', 'import'), 'get_latest_by': 'modified', 'ordering': ('-modified', '-created'), 'verbose_name': 'Patient Health Questionnaire-9 (PHQ-9)', 'verbose_name_plural': 'Patient Health Questionnaires-9 (PHQ-9)'},
        ),
        migrations.RenameField(
            model_name='historicalpatienthealth',
            old_name='phpthough',
            new_name='ph9though',
        ),
        migrations.RenameField(
            model_name='patienthealth',
            old_name='phpthough',
            new_name='ph9though',
        ),
        migrations.RemoveField(
            model_name='clinicalreview',
            name='health_insurance',
        ),
        migrations.RemoveField(
            model_name='clinicalreview',
            name='health_insurance_monthly_pay',
        ),
        migrations.RemoveField(
            model_name='clinicalreview',
            name='patient_club',
        ),
        migrations.RemoveField(
            model_name='clinicalreview',
            name='patient_club_monthly_pay',
        ),
        migrations.RemoveField(
            model_name='clinicalreview',
            name='reason',
        ),
        migrations.RemoveField(
            model_name='clinicalreview',
            name='reason_other',
        ),
        migrations.RemoveField(
            model_name='clinicalreview',
            name='test_date',
        ),
        migrations.RemoveField(
            model_name='clinicalreviewbaseline',
            name='health_insurance',
        ),
        migrations.RemoveField(
            model_name='clinicalreviewbaseline',
            name='health_insurance_monthly_pay',
        ),
        migrations.RemoveField(
            model_name='clinicalreviewbaseline',
            name='patient_club',
        ),
        migrations.RemoveField(
            model_name='clinicalreviewbaseline',
            name='patient_club_monthly_pay',
        ),
        migrations.RemoveField(
            model_name='drugsupplydm',
            name='clinic_days',
        ),
        migrations.RemoveField(
            model_name='drugsupplydm',
            name='club_days',
        ),
        migrations.RemoveField(
            model_name='drugsupplydm',
            name='purchased_days',
        ),
        migrations.RemoveField(
            model_name='drugsupplyhiv',
            name='clinic_days',
        ),
        migrations.RemoveField(
            model_name='drugsupplyhiv',
            name='club_days',
        ),
        migrations.RemoveField(
            model_name='drugsupplyhiv',
            name='purchased_days',
        ),
        migrations.RemoveField(
            model_name='drugsupplyhtn',
            name='clinic_days',
        ),
        migrations.RemoveField(
            model_name='drugsupplyhtn',
            name='club_days',
        ),
        migrations.RemoveField(
            model_name='drugsupplyhtn',
            name='purchased_days',
        ),
        migrations.RemoveField(
            model_name='historicalclinicalreview',
            name='health_insurance',
        ),
        migrations.RemoveField(
            model_name='historicalclinicalreview',
            name='health_insurance_monthly_pay',
        ),
        migrations.RemoveField(
            model_name='historicalclinicalreview',
            name='patient_club',
        ),
        migrations.RemoveField(
            model_name='historicalclinicalreview',
            name='patient_club_monthly_pay',
        ),
        migrations.RemoveField(
            model_name='historicalclinicalreview',
            name='reason_other',
        ),
        migrations.RemoveField(
            model_name='historicalclinicalreview',
            name='test_date',
        ),
        migrations.RemoveField(
            model_name='historicalclinicalreviewbaseline',
            name='health_insurance',
        ),
        migrations.RemoveField(
            model_name='historicalclinicalreviewbaseline',
            name='health_insurance_monthly_pay',
        ),
        migrations.RemoveField(
            model_name='historicalclinicalreviewbaseline',
            name='patient_club',
        ),
        migrations.RemoveField(
            model_name='historicalclinicalreviewbaseline',
            name='patient_club_monthly_pay',
        ),
        migrations.RemoveField(
            model_name='historicalnextappointment',
            name='dm_clinic_appt_date',
        ),
        migrations.RemoveField(
            model_name='historicalnextappointment',
            name='hiv_clinic_appt_date',
        ),
        migrations.RemoveField(
            model_name='historicalnextappointment',
            name='htn_clinic_appt_date',
        ),
        migrations.RemoveField(
            model_name='historicalnextappointment',
            name='ncd_clinic_appt_date',
        ),
        migrations.RemoveField(
            model_name='nextappointment',
            name='dm_clinic_appt_date',
        ),
        migrations.RemoveField(
            model_name='nextappointment',
            name='hiv_clinic_appt_date',
        ),
        migrations.RemoveField(
            model_name='nextappointment',
            name='htn_clinic_appt_date',
        ),
        migrations.RemoveField(
            model_name='nextappointment',
            name='ncd_clinic_appt_date',
        ),
        migrations.AddField(
            model_name='clinicalreview',
            name='chol_dx',
            field=models.CharField(choices=[('Yes', 'Yes'), ('No', 'No'), ('N/A', 'Not applicable')], default='N/A', max_length=15, verbose_name='As of today, was the patient <u>newly</u> diagnosed with high cholesterol?'),
        ),
        migrations.AddField(
            model_name='clinicalreview',
            name='chol_reason',
            field=models.ManyToManyField(blank=True, related_name='chol_reason', to='mocca_lists.ReasonsForTesting', verbose_name='Why was the patient tested for cholesterol?'),
        ),
        migrations.AddField(
            model_name='clinicalreview',
            name='chol_reason_other',
            field=edc_model.models.fields.other_charfield.OtherCharField(blank=True, max_length=35, null=True, verbose_name='If other, please specify ...'),
        ),
        migrations.AddField(
            model_name='clinicalreview',
            name='chol_test',
            field=models.CharField(choices=[('Yes', 'Yes'), ('No', 'No'), ('N/A', 'Not applicable')], default='N/A', help_text="Note: Select `not applicable` if diagnosis previously reported. <BR>`Since last seen` includes today.<BR>If `yes', complete the initial review CRF<BR>If `not applicable`, complete the review CRF.", max_length=15, verbose_name='Since last seen, was the patient tested for high cholesterol?'),
        ),
        migrations.AddField(
            model_name='clinicalreview',
            name='chol_test_date',
            field=models.DateField(blank=True, null=True, verbose_name='Date test requested'),
        ),
        migrations.AddField(
            model_name='dmmedicationadherence',
            name='pill_count',
            field=models.IntegerField(default=0, verbose_name='Number of pills left in the bottle'),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name='historicalclinicalreview',
            name='chol_dx',
            field=models.CharField(choices=[('Yes', 'Yes'), ('No', 'No'), ('N/A', 'Not applicable')], default='N/A', max_length=15, verbose_name='As of today, was the patient <u>newly</u> diagnosed with high cholesterol?'),
        ),
        migrations.AddField(
            model_name='historicalclinicalreview',
            name='chol_reason_other',
            field=edc_model.models.fields.other_charfield.OtherCharField(blank=True, max_length=35, null=True, verbose_name='If other, please specify ...'),
        ),
        migrations.AddField(
            model_name='historicalclinicalreview',
            name='chol_test',
            field=models.CharField(choices=[('Yes', 'Yes'), ('No', 'No'), ('N/A', 'Not applicable')], default='N/A', help_text="Note: Select `not applicable` if diagnosis previously reported. <BR>`Since last seen` includes today.<BR>If `yes', complete the initial review CRF<BR>If `not applicable`, complete the review CRF.", max_length=15, verbose_name='Since last seen, was the patient tested for high cholesterol?'),
        ),
        migrations.AddField(
            model_name='historicalclinicalreview',
            name='chol_test_date',
            field=models.DateField(blank=True, null=True, verbose_name='Date test requested'),
        ),
        migrations.AddField(
            model_name='historicaldmmedicationadherence',
            name='pill_count',
            field=models.IntegerField(default=0, verbose_name='Number of pills left in the bottle'),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name='historicalmedications',
            name='refill_chol',
            field=models.CharField(choices=[('Yes', 'Yes'), ('No', 'No'), ('N/A', 'Not applicable')], default='N/A', help_text='Select `not applicable` if subject has not been diagnosed and prescribed medication for Cholesterol.', max_length=25, verbose_name='Is the patient filling / refilling Cholesterol medications?'),
        ),
        migrations.AddField(
            model_name='historicalnextappointment',
            name='appt_date',
            field=models.DateField(blank=True, help_text='if applicable.', null=True, verbose_name='Next scheduled routine appointment'),
        ),
        migrations.AddField(
            model_name='medications',
            name='refill_chol',
            field=models.CharField(choices=[('Yes', 'Yes'), ('No', 'No'), ('N/A', 'Not applicable')], default='N/A', help_text='Select `not applicable` if subject has not been diagnosed and prescribed medication for Cholesterol.', max_length=25, verbose_name='Is the patient filling / refilling Cholesterol medications?'),
        ),
        migrations.AddField(
            model_name='nextappointment',
            name='appt_date',
            field=models.DateField(blank=True, help_text='if applicable.', null=True, verbose_name='Next scheduled routine appointment'),
        ),
        migrations.AlterField(
            model_name='dminitialreview',
            name='dx_location',
            field=models.ForeignKey(on_delete=django.db.models.deletion.PROTECT, to='mocca_lists.diagnosislocations', verbose_name='Where was the diagnosis made?'),
        ),
        migrations.AlterField(
            model_name='dmmedicationadherence',
            name='last_missed_pill',
            field=models.CharField(choices=[('today', 'today'), ('yesterday', 'yesterday'), ('earlier_this_week', 'earlier this week'), ('last_week', 'last week'), ('lt_month_ago', 'less than a month ago'), ('gt_month_ago', 'more than a month ago'), ('NEVER', 'have never missed taking my study pills')], max_length=25, verbose_name='When was the last time you missed your study pill?'),
        ),
        migrations.AlterField(
            model_name='dmmedicationadherence',
            name='missed_pill_reason',
            field=models.ManyToManyField(blank=True, to='mocca_lists.NonAdherenceReasons', verbose_name='Reasons for missing study pills'),
        ),
        migrations.AlterField(
            model_name='dmmedicationadherence',
            name='visual_score_slider',
            field=models.CharField(help_text='%', max_length=3, verbose_name='Visual score'),
        ),
        migrations.AlterField(
            model_name='historicaldminitialreview',
            name='dx_location',
            field=models.ForeignKey(blank=True, db_constraint=False, null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='+', to='mocca_lists.diagnosislocations', verbose_name='Where was the diagnosis made?'),
        ),
        migrations.AlterField(
            model_name='historicaldmmedicationadherence',
            name='last_missed_pill',
            field=models.CharField(choices=[('today', 'today'), ('yesterday', 'yesterday'), ('earlier_this_week', 'earlier this week'), ('last_week', 'last week'), ('lt_month_ago', 'less than a month ago'), ('gt_month_ago', 'more than a month ago'), ('NEVER', 'have never missed taking my study pills')], max_length=25, verbose_name='When was the last time you missed your study pill?'),
        ),
        migrations.AlterField(
            model_name='historicaldmmedicationadherence',
            name='visual_score_slider',
            field=models.CharField(help_text='%', max_length=3, verbose_name='Visual score'),
        ),
        migrations.AlterField(
            model_name='historicalhivinitialreview',
            name='dx_location',
            field=models.ForeignKey(blank=True, db_constraint=False, null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='+', to='mocca_lists.diagnosislocations', verbose_name='Where was the diagnosis made?'),
        ),
        migrations.AlterField(
            model_name='historicalhtninitialreview',
            name='dx_location',
            field=models.ForeignKey(blank=True, db_constraint=False, null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='+', to='mocca_lists.diagnosislocations', verbose_name='Where was the diagnosis made?'),
        ),
        migrations.AlterField(
            model_name='historicalsubjectvisitmissed',
            name='parent_action_identifier',
            field=models.CharField(blank=True, help_text='action identifier that links to parent reference model instance.', max_length=30, null=True),
        ),
        migrations.AlterField(
            model_name='historicalsubjectvisitmissed',
            name='related_action_identifier',
            field=models.CharField(blank=True, help_text='action identifier that links to related reference model instance.', max_length=30, null=True),
        ),
        migrations.AlterField(
            model_name='hivinitialreview',
            name='dx_location',
            field=models.ForeignKey(on_delete=django.db.models.deletion.PROTECT, to='mocca_lists.diagnosislocations', verbose_name='Where was the diagnosis made?'),
        ),
        migrations.AlterField(
            model_name='htninitialreview',
            name='dx_location',
            field=models.ForeignKey(on_delete=django.db.models.deletion.PROTECT, to='mocca_lists.diagnosislocations', verbose_name='Where was the diagnosis made?'),
        ),
        migrations.AlterField(
            model_name='subjectvisitmissed',
            name='action_item',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.PROTECT, to='edc_action_item.actionitem'),
        ),
        migrations.AlterField(
            model_name='subjectvisitmissed',
            name='parent_action_identifier',
            field=models.CharField(blank=True, help_text='action identifier that links to parent reference model instance.', max_length=30, null=True),
        ),
        migrations.AlterField(
            model_name='subjectvisitmissed',
            name='parent_action_item',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.PROTECT, related_name='+', to='edc_action_item.actionitem'),
        ),
        migrations.AlterField(
            model_name='subjectvisitmissed',
            name='related_action_identifier',
            field=models.CharField(blank=True, help_text='action identifier that links to related reference model instance.', max_length=30, null=True),
        ),
        migrations.AlterField(
            model_name='subjectvisitmissed',
            name='related_action_item',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.PROTECT, related_name='+', to='edc_action_item.actionitem'),
        ),
        migrations.DeleteModel(
            name='HealthEconomics',
        ),
        migrations.DeleteModel(
            name='HealthEconomicsRevised',
        ),
        migrations.DeleteModel(
            name='HistoricalHealthEconomics',
        ),
        migrations.DeleteModel(
            name='HistoricalHealthEconomicsRevised',
        ),
        migrations.DeleteModel(
            name='HistoricalReasonForVisit',
        ),
        migrations.DeleteModel(
            name='ReasonForVisit',
        ),
        migrations.AddIndex(
            model_name='drugrefillchol',
            index=models.Index(fields=['subject_visit', 'site', 'id'], name='mocca_subje_subject_838e8a_idx'),
        ),
        migrations.AddIndex(
            model_name='cholreview',
            index=models.Index(fields=['subject_visit', 'site', 'id'], name='mocca_subje_subject_91e0c8_idx'),
        ),
        migrations.AddIndex(
            model_name='cholmedicationadherence',
            index=models.Index(fields=['subject_visit', 'site', 'id'], name='mocca_subje_subject_06ba8e_idx'),
        ),
        migrations.AddIndex(
            model_name='cholinitialreview',
            index=models.Index(fields=['subject_visit', 'site', 'id'], name='mocca_subje_subject_6e62ad_idx'),
        ),
    ]



from django.test import TestCase
from edc_constants.constants import FEMALE, INCOMPLETE, MALE, NO, NOT_APPLICABLE, YES
from edc_utils import get_utcnow
from pytz import timezone

from mocca_screening.constants import (
    DIABETES_CLINIC,
    HIV_CLINIC,
    HYPERTENSION_CLINIC,
    NCD_CLINIC,
)
from mocca_subject.forms import ClinicalReviewBaselineForm

from ..mocca_test_case_mixin import MoccaTestCaseMixin


def get_now():
    return get_utcnow().astimezone(timezone("Africa/Kampala"))


class TestClinicalReviewBaseline(MoccaTestCaseMixin, TestCase):
    def setUp(self):
        super().setUp()
        # hiv clinic
        self.subject_screening_hiv = self.get_subject_screening(
            report_datetime=get_utcnow(),
            clinic_type=HIV_CLINIC,
            gender=FEMALE,
        )
        self.subject_consent_hiv = self.get_subject_consent(
            subject_screening=self.subject_screening_hiv,
            clinic_type=HIV_CLINIC,
        )
        self.subject_visit_hiv = self.get_subject_visit(
            subject_screening=self.subject_screening_hiv,
            subject_consent=self.subject_consent_hiv,
        )

        # htn clinic
        self.subject_screening_htn = self.get_subject_screening(
            report_datetime=get_utcnow(),
            clinic_type=HYPERTENSION_CLINIC,
            gender=MALE,
        )
        self.subject_consent_htn = self.get_subject_consent(
            subject_screening=self.subject_screening_htn,
            clinic_type=HYPERTENSION_CLINIC,
        )
        self.subject_visit_htn = self.get_subject_visit(
            subject_screening=self.subject_screening_htn,
            subject_consent=self.subject_consent_htn,
        )

        # diabetes clinic
        self.subject_screening_dm = self.get_subject_screening(
            report_datetime=get_utcnow(),
            clinic_type=DIABETES_CLINIC,
            gender=FEMALE,
        )
        self.subject_consent_dm = self.get_subject_consent(
            subject_screening=self.subject_screening_dm,
            clinic_type=DIABETES_CLINIC,
        )
        self.subject_visit_dm = self.get_subject_visit(
            subject_screening=self.subject_screening_dm,
            subject_consent=self.subject_consent_dm,
        )

        # NCD clinic
        self.subject_screening_ncd = self.get_subject_screening(
            report_datetime=get_utcnow(),
            clinic_type=NCD_CLINIC,
            gender=MALE,
        )
        self.subject_consent_ncd = self.get_subject_consent(
            subject_screening=self.subject_screening_ncd,
            clinic_type=NCD_CLINIC,
        )
        self.subject_visit_ncd = self.get_subject_visit(
            subject_screening=self.subject_screening_ncd,
            subject_consent=self.subject_consent_ncd,
        )

    def test_form_ok_hiv(self):
        data = {
            "subject_visit": self.subject_visit_hiv.pk,
            "report_datetime": self.subject_visit_hiv.report_datetime,
            "crf_status": INCOMPLETE,
            "hiv_test": YES,
            "hiv_test_ago": "5y",
            "hiv_dx": YES,
            "htn_test": NO,
            "htn_dx": NOT_APPLICABLE,
            "dm_test": NO,
            "dm_test_ago": None,
            "dm_dx": NOT_APPLICABLE,
            "chol_test": NO,
            "chol_test_ago": None,
            "chol_dx": NOT_APPLICABLE,
            "complications": YES,
        }
        form = ClinicalReviewBaselineForm(data=data)
        form.is_valid()
        self.assertEqual(form._errors, {})

    def test_form_ok_hypertensive(self):
        data = {
            "subject_visit": self.subject_visit_htn.pk,
            "report_datetime": self.subject_visit_htn.report_datetime,
            "crf_status": INCOMPLETE,
            "hiv_test": NO,
            "hiv_test_ago": None,
            "hiv_dx": NOT_APPLICABLE,
            "htn_test": YES,
            "htn_test_ago": "1y1m",
            "htn_dx": YES,
            "dm_test": NO,
            "dm_test_ago": None,
            "dm_dx": NOT_APPLICABLE,
            "chol_test": NO,
            "chol_test_ago": None,
            "chol_dx": NOT_APPLICABLE,
            "complications": YES,
        }
        form = ClinicalReviewBaselineForm(data=data)
        form.is_valid()
        self.assertEqual(form._errors, {})

    def test_form_ok_dm(self):
        data = {
            "subject_visit": self.subject_visit_dm.pk,
            "report_datetime": self.subject_visit_dm.report_datetime,
            "crf_status": INCOMPLETE,
            "hiv_test": NO,
            "hiv_test_ago": None,
            "hiv_dx": NOT_APPLICABLE,
            "htn_test": NO,
            "htn_test_ago": None,
            "htn_dx": NOT_APPLICABLE,
            "dm_test": YES,
            "dm_test_ago": "1y1m",
            "dm_dx": YES,
            "chol_test": NO,
            "chol_test_ago": None,
            "chol_dx": NOT_APPLICABLE,
            "complications": YES,
        }
        form = ClinicalReviewBaselineForm(data=data)
        form.is_valid()
        self.assertEqual(form._errors, {})

    def test_form_ok_chol(self):
        data = {
            "subject_visit": self.subject_visit_dm.pk,
            "report_datetime": self.subject_visit_dm.report_datetime,
            "crf_status": INCOMPLETE,
            "hiv_test": NO,
            "hiv_test_ago": None,
            "hiv_dx": NOT_APPLICABLE,
            "htn_test": NO,
            "htn_test_ago": None,
            "htn_dx": NOT_APPLICABLE,
            "dm_test": NO,
            "dm_test_ago": None,
            "dm_dx": NOT_APPLICABLE,
            "chol_test": YES,
            "chol_test_ago": "1y1m",
            "chol_dx": YES,
            "complications": YES,
        }
        form = ClinicalReviewBaselineForm(data=data)
        form.is_valid()
        self.assertEqual(form._errors, {})



# Generated by Django 3.0.9 on 2020-12-06 19:05

import edc_model_fields.fields.other_charfield
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("mocca_screening", "0022_auto_20201206_2140"),
    ]

    operations = [
        migrations.AddField(
            model_name="historicalsubjectscreening",
            name="willing_to_consent",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                default="N/A",
                max_length=25,
                verbose_name="Is the patient willing to consent to the MOCCA extension trial",
            ),
        ),
        migrations.AddField(
            model_name="subjectscreening",
            name="willing_to_consent",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                default="N/A",
                max_length=25,
                verbose_name="Is the patient willing to consent to the MOCCA extension trial",
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectscreening",
            name="care_comment",
            field=models.TextField(
                blank=True,
                null=True,
                verbose_name="Additional comments relevant to this patient's care",
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectscreening",
            name="icc_not_in_reason",
            field=models.CharField(
                choices=[
                    (
                        "icc_not_available",
                        "ICC not available (or closed) in this facility",
                    ),
                    ("moved", "Moved out of area"),
                    (
                        "dont_want",
                        "Personally chose not to continue with integrated care",
                    ),
                    (
                        "advised_to_vertical",
                        "Healthcare staff asked patient to return to vertical care",
                    ),
                    ("referred_out", "Referred to another facility without an ICC"),
                    ("N/A", "Not applicable"),
                ],
                default="N/A",
                max_length=25,
                verbose_name="If not integrated care, why not?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectscreening",
            name="icc_since_mocca",
            field=models.CharField(
                choices=[
                    ("Yes", "Yes"),
                    ("partially", "Partially"),
                    ("N/A", "Not applicable"),
                ],
                default="N/A",
                max_length=25,
                verbose_name="Has the patient received integrated care `continuously` since the leaving the MOCCA (orig) trial until now?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectscreening",
            name="icc_since_mocca_comment",
            field=edc_model_fields.fields.other_charfield.OtherCharField(
                blank=True,
                max_length=35,
                null=True,
                verbose_name="If PARTIALLY, please explain",
            ),
        ),
        migrations.AlterField(
            model_name="subjectscreening",
            name="care_comment",
            field=models.TextField(
                blank=True,
                null=True,
                verbose_name="Additional comments relevant to this patient's care",
            ),
        ),
        migrations.AlterField(
            model_name="subjectscreening",
            name="icc_not_in_reason",
            field=models.CharField(
                choices=[
                    (
                        "icc_not_available",
                        "ICC not available (or closed) in this facility",
                    ),
                    ("moved", "Moved out of area"),
                    (
                        "dont_want",
                        "Personally chose not to continue with integrated care",
                    ),
                    (
                        "advised_to_vertical",
                        "Healthcare staff asked patient to return to vertical care",
                    ),
                    ("referred_out", "Referred to another facility without an ICC"),
                    ("N/A", "Not applicable"),
                ],
                default="N/A",
                max_length=25,
                verbose_name="If not integrated care, why not?",
            ),
        ),
        migrations.AlterField(
            model_name="subjectscreening",
            name="icc_since_mocca",
            field=models.CharField(
                choices=[
                    ("Yes", "Yes"),
                    ("partially", "Partially"),
                    ("N/A", "Not applicable"),
                ],
                default="N/A",
                max_length=25,
                verbose_name="Has the patient received integrated care `continuously` since the leaving the MOCCA (orig) trial until now?",
            ),
        ),
        migrations.AlterField(
            model_name="subjectscreening",
            name="icc_since_mocca_comment",
            field=edc_model_fields.fields.other_charfield.OtherCharField(
                blank=True,
                max_length=35,
                null=True,
                verbose_name="If PARTIALLY, please explain",
            ),
        ),
    ]



from django.contrib import admin
from django_audit_fields.admin import audit_fieldset_tuple
from edc_crf.admin import crf_status_fieldset_tuple
from edc_form_label.form_label_modeladmin_mixin import FormLabelModelAdminMixin
from edc_model_admin import SimpleHistoryAdmin

from ..admin_site import mocca_subject_admin
from ..forms import DmInitialReviewForm
from ..models import DmInitialReview
from .modeladmin_mixins import CrfModelAdminMixin


@admin.register(DmInitialReview, site=mocca_subject_admin)
class DmInitialReviewAdmin(CrfModelAdminMixin, FormLabelModelAdminMixin, SimpleHistoryAdmin):

    form = DmInitialReviewForm

    fieldsets = (
        (None, {"fields": ("subject_visit", "report_datetime")}),
        (
            "Diagnosis, Treatment ans Monitoring",
            {
                "fields": (
                    "dx_ago",
                    "dx_date",
                    "dx_location",
                    "dx_location_other",
                    "managed_by",
                    "med_start_ago",
                )
            },
        ),
        crf_status_fieldset_tuple,
        audit_fieldset_tuple,
    )

    radio_fields = {
        "crf_status": admin.VERTICAL,
        "managed_by": admin.VERTICAL,
        "dx_location": admin.VERTICAL,
    }

    def get_form(self, request, obj=None, **kwargs):
        form = super().get_form(request, obj=obj, **kwargs)
        form = self.replace_label_text(
            form, "ncd_condition_label", self.model.ncd_condition_label
        )
        return form



from django import forms
from edc_constants.constants import NO
from edc_crf.forms import CrfFormValidatorMixin
from edc_crf.modelform_mixins import CrfModelFormMixin
from edc_dx_review.utils import raise_if_clinical_review_does_not_exist
from edc_form_validators.form_validator import FormValidator

from ..models import CholReview


class CholReviewFormValidator(
    CrfFormValidatorMixin,
    FormValidator,
):
    def clean(self):
        raise_if_clinical_review_does_not_exist(self.cleaned_data.get("subject_visit"))
        self.validate_care_delivery()

    def validate_care_delivery(self) -> None:
        self.required_if(NO, field="care_delivery", field_required="care_delivery_other")


class CholReviewForm(CrfModelFormMixin, forms.ModelForm):
    form_validator_cls = CholReviewFormValidator

    class Meta:
        model = CholReview
        fields = "__all__"



from django.contrib import admin
from django_audit_fields.admin import ModelAdminAuditFieldsMixin, audit_fieldset_tuple
from edc_model_admin import (
    ModelAdminFormAutoNumberMixin,
    ModelAdminFormInstructionsMixin,
    TemplatesModelAdminMixin,
)
from edc_model_admin.model_admin_simple_history import SimpleHistoryAdmin
from edc_sites import get_current_country

from ..admin_site import mocca_screening_admin
from ..forms import MoccaRegisterContactForm, MoccaRegisterForm
from ..mocca_original_sites import get_mocca_sites_by_country
from ..models import MoccaRegister, MoccaRegisterContact
from .changelist_buttons import (
    CareStatusButton,
    ScreeningButton,
    SubjectRefusalScreeningButton,
)
from .list_filters import CallListFilter, ContactAttemptsListFilter, ScreenedListFilter


class MoccaRegisterContactInlineMixin:
    model = MoccaRegisterContact
    form = MoccaRegisterContactForm
    extra = 0
    readonly_fields = ["report_datetime"]
    radio_fields = {
        "answered": admin.VERTICAL,
        "respondent": admin.VERTICAL,
        "survival_status": admin.VERTICAL,
        "willing_to_attend": admin.VERTICAL,
        "icc": admin.VERTICAL,
        "call_again": admin.VERTICAL,
    }


class AddMoccaRegisterContactInline(
    ModelAdminAuditFieldsMixin, MoccaRegisterContactInlineMixin, admin.StackedInline
):
    fieldsets = (
        [None, {"fields": ("report_datetime",)}],
        (
            "Details of the call",
            {
                "fields": (
                    "answered",
                    "respondent",
                    "survival_status",
                    "death_date",
                    "willing_to_attend",
                    "icc",
                    "next_appt_date",
                    "call_again",
                    "comment",
                ),
            },
        ),
    )
    verbose_name = "New Contact Attempt"
    verbose_name_plural = "New Contact Attempt"

    def has_change_permission(self, request, obj=None):
        return True

    def get_queryset(self, request):
        return MoccaRegisterContact.objects.none()


class ViewMoccaRegisterContactInline(
    ModelAdminAuditFieldsMixin, MoccaRegisterContactInlineMixin, admin.StackedInline
):

    fieldsets = (
        [None, {"fields": (("report_datetime", "answered"),)}],
        (
            "Details of the call",
            {
                "classes": ("collapse",),
                "fields": (
                    "respondent",
                    "survival_status",
                    "death_date",
                    "willing_to_attend",
                    "icc",
                    "next_appt_date",
                    "call_again",
                    "comment",
                ),
            },
        ),
    )
    verbose_name = "Past Contact Attempt"
    verbose_name_plural = "Past Contact Attempts"

    def has_add_permission(self, request, obj):
        return False

    def has_change_permission(self, request, obj=None):
        return False


@admin.register(MoccaRegister, site=mocca_screening_admin)
class MoccaRegisterAdmin(
    TemplatesModelAdminMixin,
    ModelAdminFormAutoNumberMixin,
    ModelAdminFormInstructionsMixin,
    SimpleHistoryAdmin,
):
    form = MoccaRegisterForm
    inlines = [AddMoccaRegisterContactInline, ViewMoccaRegisterContactInline]
    ordering = ["mocca_study_identifier"]
    show_object_tools = True
    list_per_page = 15

    changelist_url_name = "mocca_screening_admin:mocca_screening_moccaregister_changelist"

    fieldsets = (
        [None, {"fields": ("screening_identifier",)}],
        [
            "Original Enrollment Data",
            {
                "fields": (
                    "mocca_study_identifier",
                    "mocca_screening_identifier",
                    "mocca_site",
                    "first_name",
                    "last_name",
                    "initials",
                    "gender",
                    "dob",
                    "birth_year",
                    "age_in_years",
                )
            },
        ],
        [
            "Contact",
            {
                "fields": (
                    "notes",
                    "tel_one",
                    "tel_two",
                    "tel_three",
                    "best_tel",
                    "subject_present",
                )
            },
        ],
        audit_fieldset_tuple,
    )

    list_display = (
        "mocca_patient",
        "call_now",
        "care_status",
        "refusal",
        "screen",
        "date_last_called",
        "next_appt_date",
        "user_modified",
    )

    list_display_links = ("mocca_patient", "call_now")

    list_filter = (
        ScreenedListFilter,
        ContactAttemptsListFilter,
        CallListFilter,
        "date_last_called",
        "next_appt_date",
        "gender",
        "created",
        "modified",
    )

    radio_fields = {
        "best_tel": admin.VERTICAL,
        "call": admin.VERTICAL,
        "gender": admin.VERTICAL,
        "mocca_site": admin.VERTICAL,
        "subject_present": admin.VERTICAL,
    }

    search_fields = (
        "mocca_study_identifier",
        "initials",
        "mocca_screening_identifier",
        "screening_identifier",
        "user_modified",
        "user_created",
    )

    def call_now(self, obj):
        return f"{obj.call} ({obj.contact_attempts})"

    call_now.admin_order_field = "call"

    def mocca_patient(self, obj):
        return str(obj)

    mocca_patient.admin_order_field = "mocca_study_identifier"

    def get_readonly_fields(self, request, obj=None):
        readonly_fields = super().get_readonly_fields(request, obj=None)
        fields = [
            "contact_attempts",
            "screening_identifier",
            "mocca_study_identifier",
            "mocca_screening_identifier",
            "mocca_site",
        ]
        readonly_fields = list(readonly_fields)
        for f in fields:
            if f not in readonly_fields:
                readonly_fields.append(f)
        readonly_fields = tuple(readonly_fields)
        return readonly_fields

    def formfield_for_foreignkey(self, db_field, request, **kwargs):
        if db_field.name == "mocca_site":
            sites = get_mocca_sites_by_country(country=get_current_country())
            kwargs["queryset"] = db_field.related_model.objects.filter(
                name__in=[v.name for v in sites.values()]
            )
        return super().formfield_for_foreignkey(db_field, request, **kwargs)

    def screen(self, obj=None):
        """Returns a rendered screening button or `empty` display
        value.
        """
        button = ScreeningButton(
            mocca_register=obj,
            changelist_url_name=self.changelist_url_name,
        )
        return button.rendered or self.get_empty_value_display()

    def care_status(self, obj=None):
        """Returns a rendered care_status button or `empty` display
        value.
        """
        button = CareStatusButton(
            mocca_register=obj,
            changelist_url_name=self.changelist_url_name,
        )
        return button.rendered or self.get_empty_value_display()

    care_status.short_description = "Care Status"

    def refusal(self, obj=None):
        """Returns a rendered care_status button or `empty` display
        value.
        """
        button = SubjectRefusalScreeningButton(
            mocca_register=obj,
            changelist_url_name=self.changelist_url_name,
        )
        return button.rendered or self.get_empty_value_display()



# Generated by Django 3.0.9 on 2020-12-03 23:17

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("mocca_screening", "0004_auto_20201203_1757"),
    ]

    operations = [
        migrations.AddField(
            model_name="historicalmoccaregister",
            name="contact_attempts",
            field=models.IntegerField(default=0),
        ),
        migrations.AddField(
            model_name="moccaregister",
            name="contact_attempts",
            field=models.IntegerField(default=0),
        ),
    ]



from datetime import datetime
from pprint import pprint
from typing import Optional

from dateutil.relativedelta import relativedelta
from django.contrib.auth import get_user_model
from django.contrib.auth.models import Group
from django.urls import reverse
from edc_appointment.tests.appointment_test_case_mixin import AppointmentTestCaseMixin
from edc_constants.constants import FEMALE, NO, NOT_APPLICABLE, YES
from edc_facility.import_holidays import import_holidays
from edc_list_data.site_list_data import site_list_data
from edc_randomization.randomization_list_importer import RandomizationListImporter
from edc_randomization.site_randomizers import site_randomizers
from edc_sites import (
    add_or_update_django_sites,
    get_current_country,
    get_sites_by_country,
)
from edc_sites.tests.site_test_case_mixin import SiteTestCaseMixin
from edc_utils.date import get_utcnow
from edc_visit_schedule.constants import DAY1
from edc_visit_tracking.constants import SCHEDULED, UNSCHEDULED
from edc_visit_tracking.stubs import SubjectVisitModelStub
from model_bakery import baker

from mocca_consent.models import SubjectConsent
from mocca_screening.constants import NO_INTERRUPTION
from mocca_screening.forms import SubjectScreeningForm
from mocca_screening.import_mocca_register import import_mocca_register
from mocca_screening.mocca_original_sites import get_mocca_sites_by_country
from mocca_screening.models import MoccaRegister, SubjectScreening
from mocca_sites.sites import fqdn
from mocca_subject.models import SubjectVisit

User = get_user_model()


def age_in_years(birth_year: int) -> int:
    return datetime.now().year - birth_year


def login(testcase, user=None, superuser=None, groups=None):
    user = testcase.user if user is None else user
    superuser = True if superuser is None else superuser
    if not superuser:
        user.is_superuser = False
        user.is_active = True
        user.save()
        for group_name in groups:
            group = Group.objects.get(name=group_name)
            user.groups.add(group)
    form = testcase.app.get(reverse("home_url")).maybe_follow().form
    form["username"] = user.username
    form["password"] = "pass"
    return form.submit()


class MoccaTestCaseMixin(AppointmentTestCaseMixin, SiteTestCaseMixin):
    fqdn = fqdn

    default_sites = get_sites_by_country("uganda")

    site_names = [s.name for s in default_sites]

    import_randomization_list = True

    subject_visit_model_cls = SubjectVisit

    mocca_sites = []

    changelist_url_name = "mocca_screening_admin:mocca_screening_moccaregister_changelist"

    @classmethod
    def setUpTestData(cls):
        add_or_update_django_sites(sites=get_sites_by_country("uganda"))
        site_list_data.initialize()
        site_list_data.autodiscover()
        import_holidays(test=True)
        # GroupPermissionsUpdater(codenames_by_group=get_codenames_by_group(), verbose=True)
        if cls.import_randomization_list:
            randomizer_cls = site_randomizers.get("default")
            RandomizationListImporter(
                randomizer_cls=randomizer_cls, verbose=False, sid_count_for_tests=2
            )
        cls.mocca_sites = get_mocca_sites_by_country(country=get_current_country())
        import_mocca_register()

    def setUp(self):
        self.user = User.objects.create_superuser("user_login", "u@example.com", "pass")

    def login(self, **kwargs):
        return login(self, **kwargs)

    # def login(self, user=None, superuser=None, groups=None):
    #     user = self.user if user is None else user
    #     superuser = True if superuser is None else superuser
    #     if not superuser:
    #         user.is_superuser = False
    #         user.is_active = True
    #         user.save()
    #         for group_name in groups:
    #             group = Group.objects.get(name=group_name)
    #             user.groups.add(group)
    #     return self.client.force_login(user or self.user)

    def get_mocca_register(self, gender: str) -> MoccaRegister:
        mocca_study_identifiers = SubjectScreening.objects.values_list(
            "mocca_study_identifier", flat=True
        )
        return MoccaRegister.objects.filter(
            gender=gender or FEMALE, mocca_site__name__in=self.mocca_sites
        ).exclude(mocca_study_identifier__in=mocca_study_identifiers)[0]

    def get_subject_screening_form_data(
        self, mocca_register: Optional[MoccaRegister] = None, gender: Optional[str] = None
    ) -> dict:
        if not mocca_register:
            mocca_register = self.get_mocca_register(gender)

        return {
            "screening_consent": YES,
            "report_datetime": get_utcnow(),
            "mocca_participant": YES,
            "mocca_register": mocca_register,
            "mocca_site": str(mocca_register.mocca_site.id),
            "mocca_study_identifier": mocca_register.mocca_study_identifier,
            "initials": mocca_register.initials,
            "gender": mocca_register.gender,
            "birth_year": mocca_register.birth_year,
            "age_in_years": age_in_years(mocca_register.birth_year),
            "care": YES,
            "care_facility_location": YES,
            "icc_since_mocca": NO_INTERRUPTION,
            "icc": YES,
            "icc_not_in_reason": NOT_APPLICABLE,
            "unsuitable_for_study": NO,
            "unsuitable_agreed": NOT_APPLICABLE,
            "consent_ability": YES,
            "willing_to_consent": YES,
            "pregnant": NO if mocca_register.gender == FEMALE else NOT_APPLICABLE,
            "requires_acute_care": NO,
        }

    def get_subject_screening(
        self,
        report_datetime: Optional[datetime] = None,
        eligibility_datetime: Optional[datetime] = None,
        gender: Optional[str] = None,
        **kwargs
    ) -> SubjectScreening:
        data = self.get_subject_screening_form_data(gender=gender)
        data.update(report_datetime=report_datetime or get_utcnow(), **kwargs)
        form = SubjectScreeningForm(data=data, instance=None)
        form.is_valid()
        try:
            form.save()
        except ValueError:
            pprint(form._errors)
            raise

        subject_screening = SubjectScreening.objects.get(
            screening_identifier=form.instance.screening_identifier
        )

        self.assertTrue(subject_screening.eligible)

        if eligibility_datetime:
            subject_screening.eligibility_datetime = eligibility_datetime
            subject_screening.save()

        return subject_screening

    @staticmethod
    def get_subject_consent(subject_screening, consent_datetime=None, **kwargs):
        options = dict(
            user_created="erikvw",
            user_modified="erikvw",
            screening_identifier=subject_screening.screening_identifier,
            initials=subject_screening.initials,
            dob=get_utcnow().date() - relativedelta(years=subject_screening.age_in_years),
            site=subject_screening.site,
            consent_datetime=consent_datetime or get_utcnow(),
        )
        options.update(**kwargs)
        return baker.make_recipe("mocca_consent.subjectconsent", **options)

    def get_subject_visit(
        self,
        visit_code=None,
        visit_code_sequence=None,
        subject_screening=None,
        subject_consent=None,
        reason=None,
        appointment=None,
        appt_datetime=None,
    ):
        reason = reason or SCHEDULED
        if not appointment:
            subject_screening = subject_screening or self.get_subject_screening()
            subject_consent = subject_consent or self.get_subject_consent(subject_screening)
            appointment = self.get_appointment(
                subject_identifier=subject_consent.subject_identifier,
                visit_code=visit_code or DAY1,
                visit_code_sequence=(
                    visit_code_sequence if visit_code_sequence is not None else 0
                ),
                reason=reason,
                appt_datetime=appt_datetime,
            )
        return self.subject_visit_model_cls.objects.create(
            appointment=appointment, reason=reason
        )

    def get_next_subject_visit(
        self,
        subject_visit: SubjectVisitModelStub = None,
        reason=None,
        appt_datetime=None,
    ) -> SubjectVisitModelStub:
        visit_code = (
            subject_visit.appointment.visit_code
            if reason == UNSCHEDULED
            else subject_visit.appointment.next.visit_code
        )
        # visit_code_sequence will increment in get_subject_visit
        visit_code_sequence = (
            subject_visit.appointment.visit_code_sequence if reason == UNSCHEDULED else 0
        )
        return self.get_subject_visit(
            visit_code=visit_code,
            visit_code_sequence=visit_code_sequence,
            reason=reason,
            appt_datetime=appt_datetime,
            subject_screening=SubjectScreening.objects.get(
                subject_identifier=subject_visit.subject_identifier
            ),
            subject_consent=SubjectConsent.objects.get(
                subject_identifier=subject_visit.subject_identifier
            ),
        )



from django.apps import apps as django_apps

MOCCA_AUDITOR = "MOCCA_AUDITOR"
MOCCA_CLINIC = "MOCCA_CLINIC"
MOCCA_CLINIC_SUPER = "MOCCA_CLINIC_SUPER"
MOCCA_EXPORT = "MOCCA_EXPORT"

clinic_codenames = []
autocomplete_models = ["mocca_subject.rx"]

for app_config in django_apps.get_app_configs():
    if app_config.name in [
        "mocca_lists",
    ]:
        for model_cls in app_config.get_models():
            for prefix in ["view"]:
                clinic_codenames.append(
                    f"{app_config.name}.{prefix}_{model_cls._meta.model_name}"
                )

for app_config in django_apps.get_app_configs():
    if app_config.name in [
        "mocca_prn",
        "mocca_screening",
        "mocca_subject",
        "mocca_consent",
    ]:
        for model_cls in app_config.get_models():
            if "historical" in model_cls._meta.label_lower:
                clinic_codenames.append(f"{app_config.name}.view_{model_cls._meta.model_name}")
            elif model_cls._meta.label_lower in autocomplete_models:
                clinic_codenames.append(f"{app_config.name}.view_{model_cls._meta.model_name}")
            else:
                for prefix in ["add_", "change_", "view_", "delete_"]:
                    clinic_codenames.append(
                        f"{app_config.name}.{prefix}{model_cls._meta.model_name}"
                    )
clinic_codenames.sort()


ae_local_reviewer = [
    "mocca_subject.add_aelocalreview",
    "mocca_subject.change_aelocalreview",
    "mocca_subject.delete_aelocalreview",
    "mocca_subject.view_aelocalreview",
    "mocca_subject.view_historicalaelocalreview",
]
ae_sponsor_reviewer = [
    "mocca_subject.add_aesponsorreview",
    "mocca_subject.change_aesponsorreview",
    "mocca_subject.delete_aesponsorreview",
    "mocca_subject.view_aesponsorreview",
    "mocca_subject.view_historicalaesponsorreview",
]



# Generated by Django 3.0.9 on 2020-12-16 01:17

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ("mocca_subject", "0003_auto_20201215_0241"),
    ]

    operations = [
        migrations.RemoveField(
            model_name="reasonforvisit",
            name="health_services",
        ),
    ]



# Generated by Django 3.1.6 on 2021-02-25 03:04

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('mocca_screening', '0010_auto_20201217_0626'),
    ]

    operations = [
        migrations.AlterField(
            model_name='historicalsubjectscreening',
            name='mocca_study_identifier',
            field=models.CharField(db_index=True, help_text='Format must match original identifier. e.g. 12-3456 for UG, 123456 for TZ', max_length=25, verbose_name='MOCCA (original) study identifier'),
        ),
        migrations.AlterField(
            model_name='historicalsubjectscreening',
            name='subject_identifier',
            field=models.CharField(blank=True, max_length=50, null=True),
        ),
        migrations.AlterField(
            model_name='subjectscreening',
            name='mocca_study_identifier',
            field=models.CharField(help_text='Format must match original identifier. e.g. 12-3456 for UG, 123456 for TZ', max_length=25, unique=True, verbose_name='MOCCA (original) study identifier'),
        ),
        migrations.AlterField(
            model_name='subjectscreening',
            name='subject_identifier',
            field=models.CharField(blank=True, max_length=50, null=True),
        ),
    ]



# Generated by Django 3.1.8 on 2021-04-23 11:51

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('mocca_lists', '0004_auto_20210228_2049'),
    ]

    operations = [
        migrations.AlterField(
            model_name='arvdrugs',
            name='id',
            field=models.AutoField(primary_key=True, serialize=False),
        ),
        migrations.AlterField(
            model_name='arvregimens',
            name='id',
            field=models.AutoField(primary_key=True, serialize=False),
        ),
        migrations.AlterField(
            model_name='choltreatments',
            name='id',
            field=models.AutoField(primary_key=True, serialize=False),
        ),
        migrations.AlterField(
            model_name='clinicservices',
            name='id',
            field=models.AutoField(primary_key=True, serialize=False),
        ),
        migrations.AlterField(
            model_name='conditions',
            name='id',
            field=models.AutoField(primary_key=True, serialize=False),
        ),
        migrations.AlterField(
            model_name='diagnosislocations',
            name='id',
            field=models.AutoField(primary_key=True, serialize=False),
        ),
        migrations.AlterField(
            model_name='dmtreatments',
            name='id',
            field=models.AutoField(primary_key=True, serialize=False),
        ),
        migrations.AlterField(
            model_name='drugpaysources',
            name='id',
            field=models.AutoField(primary_key=True, serialize=False),
        ),
        migrations.AlterField(
            model_name='htntreatments',
            name='id',
            field=models.AutoField(primary_key=True, serialize=False),
        ),
        migrations.AlterField(
            model_name='moccaoriginalsites',
            name='id',
            field=models.AutoField(primary_key=True, serialize=False),
        ),
        migrations.AlterField(
            model_name='nonadherencereasons',
            name='id',
            field=models.AutoField(primary_key=True, serialize=False),
        ),
        migrations.AlterField(
            model_name='offstudyreasons',
            name='id',
            field=models.AutoField(primary_key=True, serialize=False),
        ),
        migrations.AlterField(
            model_name='reasonsfortesting',
            name='id',
            field=models.AutoField(primary_key=True, serialize=False),
        ),
        migrations.AlterField(
            model_name='refillconditions',
            name='id',
            field=models.AutoField(primary_key=True, serialize=False),
        ),
        migrations.AlterField(
            model_name='rxmodificationreasons',
            name='id',
            field=models.AutoField(primary_key=True, serialize=False),
        ),
        migrations.AlterField(
            model_name='rxmodifications',
            name='id',
            field=models.AutoField(primary_key=True, serialize=False),
        ),
        migrations.AlterField(
            model_name='subjectvisitmissedreasons',
            name='id',
            field=models.AutoField(primary_key=True, serialize=False),
        ),
        migrations.AlterField(
            model_name='transportchoices',
            name='id',
            field=models.AutoField(primary_key=True, serialize=False),
        ),
        migrations.AlterField(
            model_name='visitreasons',
            name='id',
            field=models.AutoField(primary_key=True, serialize=False),
        ),
    ]



# Generated by Django 3.1.7 on 2021-04-12 19:37

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('mocca_screening', '0011_auto_20210225_0604'),
    ]

    operations = [
        migrations.AlterField(
            model_name='historicalmoccaregistercontact',
            name='icc',
            field=models.CharField(choices=[('Yes', 'Yes'), ('No', 'No'), ('not_sure', 'Not sure'), ('N/A', 'Not applicable')], help_text='Either at this facility or elsewhere', max_length=25, null=True, verbose_name='Does the patient currently receive regular integrated care'),
        ),
        migrations.AlterField(
            model_name='moccaregistercontact',
            name='icc',
            field=models.CharField(choices=[('Yes', 'Yes'), ('No', 'No'), ('not_sure', 'Not sure'), ('N/A', 'Not applicable')], help_text='Either at this facility or elsewhere', max_length=25, null=True, verbose_name='Does the patient currently receive regular integrated care'),
        ),
    ]



from edc_model import models as edc_models

from ..model_mixins import CrfModelMixin
from .model_mixins import ComplicationsFollowupMixin


class ComplicationsFollowup(
    ComplicationsFollowupMixin, CrfModelMixin, edc_models.BaseUuidModel
):
    class Meta(CrfModelMixin.Meta, edc_models.BaseUuidModel.Meta):
        verbose_name = "Complications: Followup"
        verbose_name_plural = "Complications: Followup"



# Generated by Django 3.1.7 on 2021-04-13 17:00

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('mocca_screening', '0013_auto_20210413_1942'),
    ]

    operations = [
        migrations.AddField(
            model_name='carestatus',
            name='willing_to_answer',
            field=models.CharField(choices=[('Yes', 'Yes'), ('No', 'No')], default='Yes', max_length=15, verbose_name='Is the patient willing to provide information about their care status?'),
        ),
        migrations.AddField(
            model_name='historicalcarestatus',
            name='willing_to_answer',
            field=models.CharField(choices=[('Yes', 'Yes'), ('No', 'No')], default='Yes', max_length=15, verbose_name='Is the patient willing to provide information about their care status?'),
        ),
    ]



from typing import Optional, Protocol

from edc_constants.constants import NO, NOT_APPLICABLE, YES
from edc_screening.screening_eligibility import ScreeningEligibility

from .stubs import SubjectScreeningModelStub


class Stub(Protocol):
    model_obj: SubjectScreeningModelStub


class MoccaScreeningEligibility(ScreeningEligibility):
    def assess_eligibility(self: Stub):
        if self.model_obj.unsuitable_for_study == YES:
            self.eligible = NO
        elif (
            self.model_obj.mocca_register
            and self.model_obj.pregnant in [NO, NOT_APPLICABLE]
            and self.model_obj.care == YES
            and self.model_obj.requires_acute_care == NO
            and self.model_obj.willing_to_consent == YES
        ):
            self.eligible = YES
        else:
            self.eligible = NO
        self.reasons_ineligible = self.get_reasons_ineligible()

    def update_model(self):
        self.model_obj.eligible = self.eligible
        self.model_obj.reasons_ineligible = "|".join(self.reasons_ineligible.values())

    def get_reasons_ineligible(self: Stub) -> dict:
        """Returns a dictionary of reasons ineligible."""
        reasons_ineligible = {}
        if self.model_obj.unsuitable_for_study == YES:
            reasons_ineligible.update(unsuitable_for_study="Subject unsuitable")
        if self.model_obj.care != YES:
            reasons_ineligible.update(not_in_care="Not in care")
        if self.model_obj.pregnant not in [NO, NOT_APPLICABLE]:
            reasons_ineligible.update(pregnant="Pregnant (unconfirmed)")
        if self.model_obj.requires_acute_care != NO:
            reasons_ineligible.update(requires_acute_care="Requires acute care")
        if self.model_obj.willing_to_consent != YES:
            reasons_ineligible.update(unwilling_to_consent="Not willing to consent")
        return reasons_ineligible



# Generated by Django 3.1.6 on 2021-02-28 22:10

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('mocca_subject', '0012_auto_20210301_0054'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='glucosebaseline',
            options={'verbose_name': 'Glucose: Baseline', 'verbose_name_plural': 'Glucose: Baseline'},
        ),
        migrations.AlterModelOptions(
            name='historicalglucosebaseline',
            options={'get_latest_by': 'history_date', 'ordering': ('-history_date', '-history_id'), 'verbose_name': 'historical Glucose: Baseline'},
        ),
        migrations.AlterField(
            model_name='dmreview',
            name='glucose_fasted',
            field=models.CharField(blank=True, choices=[('Yes', 'Yes'), ('No', 'No')], max_length=15, null=True, verbose_name='Has the participant fasted?'),
        ),
        migrations.AlterField(
            model_name='dmreview',
            name='glucose_units',
            field=models.CharField(blank=True, choices=[('mg/dL', 'mg/dL'), ('mmol/L', 'mmol/L (millimoles/L)'), ('N/A', 'Not applicable')], default='N/A', max_length=15, null=True, verbose_name='Units (glucose)'),
        ),
        migrations.AlterField(
            model_name='glucose',
            name='glucose_fasted',
            field=models.CharField(blank=True, choices=[('Yes', 'Yes'), ('No', 'No')], max_length=15, null=True, verbose_name='Has the participant fasted?'),
        ),
        migrations.AlterField(
            model_name='glucose',
            name='glucose_units',
            field=models.CharField(blank=True, choices=[('mg/dL', 'mg/dL'), ('mmol/L', 'mmol/L (millimoles/L)'), ('N/A', 'Not applicable')], default='N/A', max_length=15, null=True, verbose_name='Units (glucose)'),
        ),
        migrations.AlterField(
            model_name='historicaldmreview',
            name='glucose_fasted',
            field=models.CharField(blank=True, choices=[('Yes', 'Yes'), ('No', 'No')], max_length=15, null=True, verbose_name='Has the participant fasted?'),
        ),
        migrations.AlterField(
            model_name='historicaldmreview',
            name='glucose_units',
            field=models.CharField(blank=True, choices=[('mg/dL', 'mg/dL'), ('mmol/L', 'mmol/L (millimoles/L)'), ('N/A', 'Not applicable')], default='N/A', max_length=15, null=True, verbose_name='Units (glucose)'),
        ),
        migrations.AlterField(
            model_name='historicalglucose',
            name='glucose_fasted',
            field=models.CharField(blank=True, choices=[('Yes', 'Yes'), ('No', 'No')], max_length=15, null=True, verbose_name='Has the participant fasted?'),
        ),
        migrations.AlterField(
            model_name='historicalglucose',
            name='glucose_units',
            field=models.CharField(blank=True, choices=[('mg/dL', 'mg/dL'), ('mmol/L', 'mmol/L (millimoles/L)'), ('N/A', 'Not applicable')], default='N/A', max_length=15, null=True, verbose_name='Units (glucose)'),
        ),
        migrations.AlterField(
            model_name='historicalglucosebaseline',
            name='glucose_fasted',
            field=models.CharField(blank=True, choices=[('Yes', 'Yes'), ('No', 'No')], max_length=15, null=True, verbose_name='Has the participant fasted?'),
        ),
        migrations.AlterField(
            model_name='historicalglucosebaseline',
            name='glucose_units',
            field=models.CharField(blank=True, choices=[('mg/dL', 'mg/dL'), ('mmol/L', 'mmol/L (millimoles/L)'), ('N/A', 'Not applicable')], default='N/A', max_length=15, null=True, verbose_name='Units (glucose)'),
        ),
    ]



# Generated by Django 3.2.11 on 2022-02-03 22:39

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('mocca_subject', '0030_auto_20220204_0116'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='arvregimens',
            options={'verbose_name': 'ARV Regimens', 'verbose_name_plural': 'ARV Regimens'},
        ),
    ]



from edc_lab_panel.panels import (
    blood_glucose_panel,
    blood_glucose_poc_panel,
    hba1c_panel,
    hba1c_poc_panel,
)
from edc_visit_schedule import FormsCollection, Requisition

from mocca_labs.panels import lipids_panel

requisitions_prn = FormsCollection(
    Requisition(show_order=10, panel=lipids_panel, required=True, additional=False),
    Requisition(show_order=20, panel=blood_glucose_panel, required=True, additional=False),
    Requisition(show_order=30, panel=blood_glucose_poc_panel, required=True, additional=False),
    Requisition(show_order=40, panel=hba1c_poc_panel, required=True, additional=False),
    Requisition(show_order=50, panel=hba1c_panel, required=True, additional=False),
    name="requisitions_prn",
)

requisitions_d1 = FormsCollection(
    Requisition(show_order=10, panel=lipids_panel, required=True, additional=False),
    name="requisitions_day1",
)
requisitions_all = FormsCollection(
    Requisition(show_order=10, panel=lipids_panel, required=False, additional=False),
    Requisition(
        show_order=30, panel=blood_glucose_poc_panel, required=False, additional=False
    ),
    name="requisitions_all",
)



from django import forms
from edc_crf.modelform_mixins import CrfModelFormMixin
from edc_glucose.form_validators import GlucoseFormValidator as BaseGlucoseFormValidator

from ..models import GlucoseBaseline


class GlucoseFormValidator(BaseGlucoseFormValidator):
    required_at_baseline = True


class GlucoseBaselineForm(CrfModelFormMixin, forms.ModelForm):
    form_validator_cls = GlucoseFormValidator

    class Meta:
        model = GlucoseBaseline
        fields = "__all__"



# Generated by Django 3.0.9 on 2020-12-04 00:30

import django_crypto_fields.fields.encrypted_text_field
from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ("mocca_screening", "0009_auto_20201204_0323"),
    ]

    operations = [
        migrations.AddField(
            model_name="historicalmoccaregister",
            name="notes",
            field=django_crypto_fields.fields.encrypted_text_field.EncryptedTextField(
                blank=True,
                help_text=" (Encryption: AES local)",
                max_length=71,
                null=True,
            ),
        ),
        migrations.AddField(
            model_name="moccaregister",
            name="notes",
            field=django_crypto_fields.fields.encrypted_text_field.EncryptedTextField(
                blank=True,
                help_text=" (Encryption: AES local)",
                max_length=71,
                null=True,
            ),
        ),
    ]



# Generated by Django 3.2.11 on 2022-02-03 22:16

import django.core.validators
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('mocca_lists', '0005_auto_20210423_1451'),
        ('mocca_subject', '0029_auto_20220131_1925'),
    ]

    operations = [
        migrations.CreateModel(
            name='ArvRegimens',
            fields=[
            ],
            options={
                'proxy': True,
                'indexes': [],
                'constraints': [],
            },
            bases=('mocca_lists.arvregimens',),
        ),
        migrations.AlterField(
            model_name='historicalsubjectvisitmissed',
            name='contact_attempts_count',
            field=models.IntegerField(blank=True, help_text='Not including pre-appointment reminders. Multiple attempts on the same day count as a single attempt.', null=True, validators=[django.core.validators.MinValueValidator(1)], verbose_name='Number of attempts made to contact participantsince the expected appointment date'),
        ),
        migrations.AlterField(
            model_name='subjectvisitmissed',
            name='contact_attempts_count',
            field=models.IntegerField(blank=True, help_text='Not including pre-appointment reminders. Multiple attempts on the same day count as a single attempt.', null=True, validators=[django.core.validators.MinValueValidator(1)], verbose_name='Number of attempts made to contact participantsince the expected appointment date'),
        ),
        migrations.AlterField(
            model_name='drugrefillhiv',
            name='rx',
            field=models.ForeignKey(on_delete=django.db.models.deletion.PROTECT, to='mocca_subject.arvregimens', verbose_name='Which medicine did the patient receive today?'),
        ),
        migrations.AlterField(
            model_name='historicaldrugrefillhiv',
            name='rx',
            field=models.ForeignKey(blank=True, db_constraint=False, null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='+', to='mocca_subject.arvregimens', verbose_name='Which medicine did the patient receive today?'),
        ),
    ]



# Generated by Django 3.1.6 on 2021-03-01 02:07

import _socket
from django.conf import settings
import django.core.validators
from django.db import migrations, models
import django.db.models.deletion
import django_audit_fields.fields.hostname_modification_field
import django_audit_fields.fields.userfield
import django_audit_fields.fields.uuid_auto_field
import django_audit_fields.models.audit_model_mixin
import django_revision.revision_field
import edc_model.models.validators.date
import edc_protocol.validators
import edc_utils.date
import edc_visit_tracking.managers
import simple_history.models
import uuid


class Migration(migrations.Migration):

    dependencies = [
        ('sites', '0002_alter_domain_unique'),
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ('edc_action_item', '0028_auto_20210203_0706'),
        ('mocca_subject', '0013_auto_20210301_0110'),
    ]

    operations = [
        migrations.AlterField(
            model_name='dmreview',
            name='glucose_fasted',
            field=models.CharField(choices=[('Yes', 'Yes'), ('No', 'No'), ('N/A', 'Not applicable')], default='N/A', max_length=15, verbose_name='Has the participant fasted?'),
        ),
        migrations.AlterField(
            model_name='dmreview',
            name='glucose_units',
            field=models.CharField(choices=[('mg/dL', 'mg/dL'), ('mmol/L', 'mmol/L (millimoles/L)'), ('N/A', 'Not applicable')], default='N/A', max_length=15, verbose_name='Units (glucose)'),
        ),
        migrations.AlterField(
            model_name='glucose',
            name='glucose_fasted',
            field=models.CharField(choices=[('Yes', 'Yes'), ('No', 'No'), ('N/A', 'Not applicable')], default='N/A', max_length=15, verbose_name='Has the participant fasted?'),
        ),
        migrations.AlterField(
            model_name='glucose',
            name='glucose_units',
            field=models.CharField(choices=[('mg/dL', 'mg/dL'), ('mmol/L', 'mmol/L (millimoles/L)'), ('N/A', 'Not applicable')], default='N/A', max_length=15, verbose_name='Units (glucose)'),
        ),
        migrations.AlterField(
            model_name='historicaldmreview',
            name='glucose_fasted',
            field=models.CharField(choices=[('Yes', 'Yes'), ('No', 'No'), ('N/A', 'Not applicable')], default='N/A', max_length=15, verbose_name='Has the participant fasted?'),
        ),
        migrations.AlterField(
            model_name='historicaldmreview',
            name='glucose_units',
            field=models.CharField(choices=[('mg/dL', 'mg/dL'), ('mmol/L', 'mmol/L (millimoles/L)'), ('N/A', 'Not applicable')], default='N/A', max_length=15, verbose_name='Units (glucose)'),
        ),
        migrations.AlterField(
            model_name='historicalglucose',
            name='glucose_fasted',
            field=models.CharField(choices=[('Yes', 'Yes'), ('No', 'No'), ('N/A', 'Not applicable')], default='N/A', max_length=15, verbose_name='Has the participant fasted?'),
        ),
        migrations.AlterField(
            model_name='historicalglucose',
            name='glucose_units',
            field=models.CharField(choices=[('mg/dL', 'mg/dL'), ('mmol/L', 'mmol/L (millimoles/L)'), ('N/A', 'Not applicable')], default='N/A', max_length=15, verbose_name='Units (glucose)'),
        ),
        migrations.AlterField(
            model_name='historicalglucosebaseline',
            name='glucose_fasted',
            field=models.CharField(choices=[('Yes', 'Yes'), ('No', 'No'), ('N/A', 'Not applicable')], default='N/A', max_length=15, verbose_name='Has the participant fasted?'),
        ),
        migrations.AlterField(
            model_name='historicalglucosebaseline',
            name='glucose_units',
            field=models.CharField(choices=[('mg/dL', 'mg/dL'), ('mmol/L', 'mmol/L (millimoles/L)'), ('N/A', 'Not applicable')], default='N/A', max_length=15, verbose_name='Units (glucose)'),
        ),
        migrations.CreateModel(
            name='HistoricalBloodResultsLipid',
            fields=[
                ('revision', django_revision.revision_field.RevisionField(blank=True, editable=False, help_text='System field. Git repository tag:branch:commit.', max_length=75, null=True, verbose_name='Revision')),
                ('created', models.DateTimeField(blank=True, default=django_audit_fields.models.audit_model_mixin.utcnow)),
                ('modified', models.DateTimeField(blank=True, default=django_audit_fields.models.audit_model_mixin.utcnow)),
                ('user_created', django_audit_fields.fields.userfield.UserField(blank=True, help_text='Updated by admin.save_model', max_length=50, verbose_name='user created')),
                ('user_modified', django_audit_fields.fields.userfield.UserField(blank=True, help_text='Updated by admin.save_model', max_length=50, verbose_name='user modified')),
                ('hostname_created', models.CharField(blank=True, default=_socket.gethostname, help_text='System field. (modified on create only)', max_length=60)),
                ('hostname_modified', django_audit_fields.fields.hostname_modification_field.HostnameModificationField(blank=True, help_text='System field. (modified on every save)', max_length=50)),
                ('device_created', models.CharField(blank=True, max_length=10)),
                ('device_modified', models.CharField(blank=True, max_length=10)),
                ('id', django_audit_fields.fields.uuid_auto_field.UUIDAutoField(blank=True, db_index=True, editable=False, help_text='System auto field. UUID primary key.')),
                ('tracking_identifier', models.CharField(db_index=True, max_length=30)),
                ('action_identifier', models.CharField(db_index=True, max_length=50)),
                ('parent_action_identifier', models.CharField(blank=True, help_text='action identifier that links to parent reference model instance.', max_length=30, null=True)),
                ('related_action_identifier', models.CharField(blank=True, help_text='action identifier that links to related reference model instance.', max_length=30, null=True)),
                ('action_item_reason', models.TextField(editable=False, null=True)),
                ('history_id', models.UUIDField(default=uuid.uuid4, editable=False, primary_key=True, serialize=False)),
                ('report_datetime', models.DateTimeField(default=edc_utils.date.get_utcnow, help_text="If reporting today, use today's date/time, otherwise use the date/time this information was reported.", validators=[edc_protocol.validators.datetime_not_before_study_start, edc_model.models.validators.date.datetime_not_future], verbose_name='Report Date')),
                ('consent_model', models.CharField(editable=False, max_length=50, null=True)),
                ('consent_version', models.CharField(editable=False, max_length=10, null=True)),
                ('results_abnormal', models.CharField(choices=[('Yes', 'Yes'), ('No', 'No')], max_length=25, verbose_name='Are any of the above results abnormal?')),
                ('results_reportable', models.CharField(choices=[('Yes', 'Yes'), ('No', 'No'), ('N/A', 'Not applicable')], help_text='If YES, this value will open Adverse Event Form.', max_length=25, verbose_name='If any results are abnormal, are results within grade 3 or above?')),
                ('summary', models.TextField(blank=True, null=True)),
                ('lipid_assay_datetime', models.DateTimeField(blank=True, null=True, validators=[edc_model.models.validators.date.datetime_not_future], verbose_name='Result Report Date and Time')),
                ('ldl', models.DecimalField(blank=True, decimal_places=2, max_digits=8, null=True, validators=[django.core.validators.MinValueValidator(0), django.core.validators.MaxValueValidator(999)], verbose_name='LDL')),
                ('ldl_units', models.CharField(blank=True, choices=[('mmol/L', 'mmol/L')], max_length=15, null=True, verbose_name='units')),
                ('ldl_abnormal', models.CharField(blank=True, choices=[('Yes', 'Yes'), ('No', 'No')], max_length=25, null=True, verbose_name='abnormal')),
                ('ldl_reportable', models.CharField(blank=True, choices=[('N/A', 'Not applicable'), ('3', 'Yes, grade 3'), ('4', 'Yes, grade 4'), ('No', 'Not reportable'), ('Already reported', 'Already reported'), ('present_at_baseline', 'Present at baseline')], max_length=25, null=True, verbose_name='reportable')),
                ('hdl', models.DecimalField(blank=True, decimal_places=2, max_digits=8, null=True, validators=[django.core.validators.MinValueValidator(0), django.core.validators.MaxValueValidator(999)], verbose_name='HDL')),
                ('hdl_units', models.CharField(blank=True, choices=[('mmol/L', 'mmol/L')], max_length=15, null=True, verbose_name='units')),
                ('hdl_abnormal', models.CharField(blank=True, choices=[('Yes', 'Yes'), ('No', 'No')], max_length=25, null=True, verbose_name='abnormal')),
                ('hdl_reportable', models.CharField(blank=True, choices=[('N/A', 'Not applicable'), ('3', 'Yes, grade 3'), ('4', 'Yes, grade 4'), ('No', 'Not reportable'), ('Already reported', 'Already reported'), ('present_at_baseline', 'Present at baseline')], max_length=25, null=True, verbose_name='reportable')),
                ('trig', models.DecimalField(blank=True, decimal_places=2, max_digits=8, null=True, validators=[django.core.validators.MinValueValidator(0), django.core.validators.MaxValueValidator(999)], verbose_name='Triglycerides')),
                ('trig_units', models.CharField(blank=True, choices=[('mmol/L', 'mmol/L')], max_length=15, null=True, verbose_name='units')),
                ('trig_abnormal', models.CharField(blank=True, choices=[('Yes', 'Yes'), ('No', 'No')], max_length=25, null=True, verbose_name='abnormal')),
                ('trig_reportable', models.CharField(blank=True, choices=[('N/A', 'Not applicable'), ('3', 'Yes, grade 3'), ('4', 'Yes, grade 4'), ('No', 'Not reportable'), ('Already reported', 'Already reported'), ('present_at_baseline', 'Present at baseline')], max_length=25, null=True, verbose_name='reportable')),
                ('history_date', models.DateTimeField()),
                ('history_change_reason', models.CharField(max_length=100, null=True)),
                ('history_type', models.CharField(choices=[('+', 'Created'), ('~', 'Changed'), ('-', 'Deleted')], max_length=1)),
                ('action_item', models.ForeignKey(blank=True, db_constraint=False, null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='+', to='edc_action_item.actionitem')),
                ('history_user', models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='+', to=settings.AUTH_USER_MODEL)),
                ('lipid_requisition', models.ForeignKey(blank=True, db_constraint=False, help_text='Start typing the requisition identifier or select one from this visit', null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='+', to='mocca_subject.subjectrequisition', verbose_name='Requisition')),
                ('parent_action_item', models.ForeignKey(blank=True, db_constraint=False, null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='+', to='edc_action_item.actionitem')),
                ('related_action_item', models.ForeignKey(blank=True, db_constraint=False, null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='+', to='edc_action_item.actionitem')),
                ('site', models.ForeignKey(blank=True, db_constraint=False, editable=False, null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='+', to='sites.site')),
                ('subject_visit', models.ForeignKey(blank=True, db_constraint=False, null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='+', to='mocca_subject.subjectvisit')),
            ],
            options={
                'verbose_name': 'historical Blood Result: Lipids',
                'ordering': ('-history_date', '-history_id'),
                'get_latest_by': 'history_date',
            },
            bases=(simple_history.models.HistoricalChanges, models.Model),
        ),
        migrations.CreateModel(
            name='HistoricalBloodResultsFbc',
            fields=[
                ('revision', django_revision.revision_field.RevisionField(blank=True, editable=False, help_text='System field. Git repository tag:branch:commit.', max_length=75, null=True, verbose_name='Revision')),
                ('created', models.DateTimeField(blank=True, default=django_audit_fields.models.audit_model_mixin.utcnow)),
                ('modified', models.DateTimeField(blank=True, default=django_audit_fields.models.audit_model_mixin.utcnow)),
                ('user_created', django_audit_fields.fields.userfield.UserField(blank=True, help_text='Updated by admin.save_model', max_length=50, verbose_name='user created')),
                ('user_modified', django_audit_fields.fields.userfield.UserField(blank=True, help_text='Updated by admin.save_model', max_length=50, verbose_name='user modified')),
                ('hostname_created', models.CharField(blank=True, default=_socket.gethostname, help_text='System field. (modified on create only)', max_length=60)),
                ('hostname_modified', django_audit_fields.fields.hostname_modification_field.HostnameModificationField(blank=True, help_text='System field. (modified on every save)', max_length=50)),
                ('device_created', models.CharField(blank=True, max_length=10)),
                ('device_modified', models.CharField(blank=True, max_length=10)),
                ('id', django_audit_fields.fields.uuid_auto_field.UUIDAutoField(blank=True, db_index=True, editable=False, help_text='System auto field. UUID primary key.')),
                ('tracking_identifier', models.CharField(db_index=True, max_length=30)),
                ('action_identifier', models.CharField(db_index=True, max_length=50)),
                ('parent_action_identifier', models.CharField(blank=True, help_text='action identifier that links to parent reference model instance.', max_length=30, null=True)),
                ('related_action_identifier', models.CharField(blank=True, help_text='action identifier that links to related reference model instance.', max_length=30, null=True)),
                ('action_item_reason', models.TextField(editable=False, null=True)),
                ('history_id', models.UUIDField(default=uuid.uuid4, editable=False, primary_key=True, serialize=False)),
                ('report_datetime', models.DateTimeField(default=edc_utils.date.get_utcnow, help_text="If reporting today, use today's date/time, otherwise use the date/time this information was reported.", validators=[edc_protocol.validators.datetime_not_before_study_start, edc_model.models.validators.date.datetime_not_future], verbose_name='Report Date')),
                ('consent_model', models.CharField(editable=False, max_length=50, null=True)),
                ('consent_version', models.CharField(editable=False, max_length=10, null=True)),
                ('results_abnormal', models.CharField(choices=[('Yes', 'Yes'), ('No', 'No')], max_length=25, verbose_name='Are any of the above results abnormal?')),
                ('results_reportable', models.CharField(choices=[('Yes', 'Yes'), ('No', 'No'), ('N/A', 'Not applicable')], help_text='If YES, this value will open Adverse Event Form.', max_length=25, verbose_name='If any results are abnormal, are results within grade 3 or above?')),
                ('summary', models.TextField(blank=True, null=True)),
                ('fbc_assay_datetime', models.DateTimeField(blank=True, null=True, validators=[edc_model.models.validators.date.datetime_not_future], verbose_name='Result Report Date and Time')),
                ('haemoglobin', models.DecimalField(blank=True, decimal_places=1, max_digits=6, null=True)),
                ('haemoglobin_units', models.CharField(blank=True, choices=[('g/dL', 'g/dL')], max_length=15, null=True, verbose_name='units')),
                ('haemoglobin_abnormal', models.CharField(blank=True, choices=[('Yes', 'Yes'), ('No', 'No')], max_length=25, null=True, verbose_name='abnormal')),
                ('haemoglobin_reportable', models.CharField(blank=True, choices=[('N/A', 'Not applicable'), ('3', 'Yes, grade 3'), ('4', 'Yes, grade 4'), ('No', 'Not reportable'), ('Already reported', 'Already reported'), ('present_at_baseline', 'Present at baseline')], max_length=25, null=True, verbose_name='reportable')),
                ('hct', models.DecimalField(blank=True, decimal_places=2, max_digits=6, null=True, validators=[django.core.validators.MinValueValidator(1.0), django.core.validators.MaxValueValidator(999.0)], verbose_name='Hematocrit')),
                ('hct_units', models.CharField(blank=True, choices=[('%', '%')], max_length=15, null=True, verbose_name='units')),
                ('hct_abnormal', models.CharField(blank=True, choices=[('Yes', 'Yes'), ('No', 'No')], max_length=25, null=True, verbose_name='abnormal')),
                ('hct_reportable', models.CharField(blank=True, choices=[('N/A', 'Not applicable'), ('3', 'Yes, grade 3'), ('4', 'Yes, grade 4'), ('No', 'Not reportable'), ('Already reported', 'Already reported'), ('present_at_baseline', 'Present at baseline')], max_length=25, null=True, verbose_name='reportable')),
                ('rbc', models.DecimalField(blank=True, decimal_places=2, max_digits=6, null=True, validators=[django.core.validators.MinValueValidator(1.0), django.core.validators.MaxValueValidator(999999.0)], verbose_name='Red blood cell count')),
                ('rbc_units', models.CharField(blank=True, choices=[('10^9/L', '10^9/L'), ('cells/mm^3', 'cells/mm^3')], max_length=15, null=True, verbose_name='units')),
                ('rbc_abnormal', models.CharField(blank=True, choices=[('Yes', 'Yes'), ('No', 'No')], max_length=25, null=True, verbose_name='abnormal')),
                ('rbc_reportable', models.CharField(blank=True, choices=[('N/A', 'Not applicable'), ('3', 'Yes, grade 3'), ('4', 'Yes, grade 4'), ('No', 'Not reportable'), ('Already reported', 'Already reported'), ('present_at_baseline', 'Present at baseline')], max_length=25, null=True, verbose_name='reportable')),
                ('wbc', models.DecimalField(blank=True, decimal_places=2, max_digits=6, null=True, verbose_name='WBC')),
                ('wbc_units', models.CharField(blank=True, choices=[('10^9/L', '10^9/L'), ('cells/mm^3', 'cells/mm<sup>3</sup>')], max_length=15, null=True, verbose_name='units')),
                ('wbc_abnormal', models.CharField(blank=True, choices=[('Yes', 'Yes'), ('No', 'No')], max_length=25, null=True, verbose_name='abnormal')),
                ('wbc_reportable', models.CharField(blank=True, choices=[('N/A', 'Not applicable'), ('3', 'Yes, grade 3'), ('4', 'Yes, grade 4'), ('No', 'Not reportable'), ('Already reported', 'Already reported'), ('present_at_baseline', 'Present at baseline')], max_length=25, null=True, verbose_name='reportable')),
                ('platelets', models.IntegerField(blank=True, null=True, validators=[django.core.validators.MinValueValidator(1), django.core.validators.MaxValueValidator(9999)])),
                ('platelets_units', models.CharField(blank=True, choices=[('10^9/L', '10^9/L'), ('cells/mm^3', 'cells/mm<sup>3</sup>')], max_length=15, null=True, verbose_name='units')),
                ('platelets_abnormal', models.CharField(blank=True, choices=[('Yes', 'Yes'), ('No', 'No')], max_length=25, null=True, verbose_name='abnormal')),
                ('platelets_reportable', models.CharField(blank=True, choices=[('N/A', 'Not applicable'), ('3', 'Yes, grade 3'), ('4', 'Yes, grade 4'), ('No', 'Not reportable'), ('Already reported', 'Already reported'), ('present_at_baseline', 'Present at baseline')], max_length=25, null=True, verbose_name='reportable')),
                ('history_date', models.DateTimeField()),
                ('history_change_reason', models.CharField(max_length=100, null=True)),
                ('history_type', models.CharField(choices=[('+', 'Created'), ('~', 'Changed'), ('-', 'Deleted')], max_length=1)),
                ('action_item', models.ForeignKey(blank=True, db_constraint=False, null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='+', to='edc_action_item.actionitem')),
                ('fbc_requisition', models.ForeignKey(blank=True, db_constraint=False, help_text='Start typing the requisition identifier or select one from this visit', null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='+', to='mocca_subject.subjectrequisition', verbose_name='Requisition')),
                ('history_user', models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='+', to=settings.AUTH_USER_MODEL)),
                ('parent_action_item', models.ForeignKey(blank=True, db_constraint=False, null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='+', to='edc_action_item.actionitem')),
                ('related_action_item', models.ForeignKey(blank=True, db_constraint=False, null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='+', to='edc_action_item.actionitem')),
                ('site', models.ForeignKey(blank=True, db_constraint=False, editable=False, null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='+', to='sites.site')),
                ('subject_visit', models.ForeignKey(blank=True, db_constraint=False, null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='+', to='mocca_subject.subjectvisit')),
            ],
            options={
                'verbose_name': 'historical blood results fbc',
                'ordering': ('-history_date', '-history_id'),
                'get_latest_by': 'history_date',
            },
            bases=(simple_history.models.HistoricalChanges, models.Model),
        ),
        migrations.CreateModel(
            name='BloodResultsLipid',
            fields=[
                ('revision', django_revision.revision_field.RevisionField(blank=True, editable=False, help_text='System field. Git repository tag:branch:commit.', max_length=75, null=True, verbose_name='Revision')),
                ('created', models.DateTimeField(blank=True, default=django_audit_fields.models.audit_model_mixin.utcnow)),
                ('modified', models.DateTimeField(blank=True, default=django_audit_fields.models.audit_model_mixin.utcnow)),
                ('user_created', django_audit_fields.fields.userfield.UserField(blank=True, help_text='Updated by admin.save_model', max_length=50, verbose_name='user created')),
                ('user_modified', django_audit_fields.fields.userfield.UserField(blank=True, help_text='Updated by admin.save_model', max_length=50, verbose_name='user modified')),
                ('hostname_created', models.CharField(blank=True, default=_socket.gethostname, help_text='System field. (modified on create only)', max_length=60)),
                ('hostname_modified', django_audit_fields.fields.hostname_modification_field.HostnameModificationField(blank=True, help_text='System field. (modified on every save)', max_length=50)),
                ('device_created', models.CharField(blank=True, max_length=10)),
                ('device_modified', models.CharField(blank=True, max_length=10)),
                ('id', django_audit_fields.fields.uuid_auto_field.UUIDAutoField(blank=True, editable=False, help_text='System auto field. UUID primary key.', primary_key=True, serialize=False)),
                ('tracking_identifier', models.CharField(max_length=30, unique=True)),
                ('action_identifier', models.CharField(max_length=50, unique=True)),
                ('parent_action_identifier', models.CharField(blank=True, help_text='action identifier that links to parent reference model instance.', max_length=30, null=True)),
                ('related_action_identifier', models.CharField(blank=True, help_text='action identifier that links to related reference model instance.', max_length=30, null=True)),
                ('action_item_reason', models.TextField(editable=False, null=True)),
                ('report_datetime', models.DateTimeField(default=edc_utils.date.get_utcnow, help_text="If reporting today, use today's date/time, otherwise use the date/time this information was reported.", validators=[edc_protocol.validators.datetime_not_before_study_start, edc_model.models.validators.date.datetime_not_future], verbose_name='Report Date')),
                ('consent_model', models.CharField(editable=False, max_length=50, null=True)),
                ('consent_version', models.CharField(editable=False, max_length=10, null=True)),
                ('results_abnormal', models.CharField(choices=[('Yes', 'Yes'), ('No', 'No')], max_length=25, verbose_name='Are any of the above results abnormal?')),
                ('results_reportable', models.CharField(choices=[('Yes', 'Yes'), ('No', 'No'), ('N/A', 'Not applicable')], help_text='If YES, this value will open Adverse Event Form.', max_length=25, verbose_name='If any results are abnormal, are results within grade 3 or above?')),
                ('summary', models.TextField(blank=True, null=True)),
                ('lipid_assay_datetime', models.DateTimeField(blank=True, null=True, validators=[edc_model.models.validators.date.datetime_not_future], verbose_name='Result Report Date and Time')),
                ('ldl', models.DecimalField(blank=True, decimal_places=2, max_digits=8, null=True, validators=[django.core.validators.MinValueValidator(0), django.core.validators.MaxValueValidator(999)], verbose_name='LDL')),
                ('ldl_units', models.CharField(blank=True, choices=[('mmol/L', 'mmol/L')], max_length=15, null=True, verbose_name='units')),
                ('ldl_abnormal', models.CharField(blank=True, choices=[('Yes', 'Yes'), ('No', 'No')], max_length=25, null=True, verbose_name='abnormal')),
                ('ldl_reportable', models.CharField(blank=True, choices=[('N/A', 'Not applicable'), ('3', 'Yes, grade 3'), ('4', 'Yes, grade 4'), ('No', 'Not reportable'), ('Already reported', 'Already reported'), ('present_at_baseline', 'Present at baseline')], max_length=25, null=True, verbose_name='reportable')),
                ('hdl', models.DecimalField(blank=True, decimal_places=2, max_digits=8, null=True, validators=[django.core.validators.MinValueValidator(0), django.core.validators.MaxValueValidator(999)], verbose_name='HDL')),
                ('hdl_units', models.CharField(blank=True, choices=[('mmol/L', 'mmol/L')], max_length=15, null=True, verbose_name='units')),
                ('hdl_abnormal', models.CharField(blank=True, choices=[('Yes', 'Yes'), ('No', 'No')], max_length=25, null=True, verbose_name='abnormal')),
                ('hdl_reportable', models.CharField(blank=True, choices=[('N/A', 'Not applicable'), ('3', 'Yes, grade 3'), ('4', 'Yes, grade 4'), ('No', 'Not reportable'), ('Already reported', 'Already reported'), ('present_at_baseline', 'Present at baseline')], max_length=25, null=True, verbose_name='reportable')),
                ('trig', models.DecimalField(blank=True, decimal_places=2, max_digits=8, null=True, validators=[django.core.validators.MinValueValidator(0), django.core.validators.MaxValueValidator(999)], verbose_name='Triglycerides')),
                ('trig_units', models.CharField(blank=True, choices=[('mmol/L', 'mmol/L')], max_length=15, null=True, verbose_name='units')),
                ('trig_abnormal', models.CharField(blank=True, choices=[('Yes', 'Yes'), ('No', 'No')], max_length=25, null=True, verbose_name='abnormal')),
                ('trig_reportable', models.CharField(blank=True, choices=[('N/A', 'Not applicable'), ('3', 'Yes, grade 3'), ('4', 'Yes, grade 4'), ('No', 'Not reportable'), ('Already reported', 'Already reported'), ('present_at_baseline', 'Present at baseline')], max_length=25, null=True, verbose_name='reportable')),
                ('action_item', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.PROTECT, to='edc_action_item.actionitem')),
                ('lipid_requisition', models.ForeignKey(blank=True, help_text='Start typing the requisition identifier or select one from this visit', null=True, on_delete=django.db.models.deletion.PROTECT, related_name='lipid', to='mocca_subject.subjectrequisition', verbose_name='Requisition')),
                ('parent_action_item', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.PROTECT, related_name='+', to='edc_action_item.actionitem')),
                ('related_action_item', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.PROTECT, related_name='+', to='edc_action_item.actionitem')),
                ('site', models.ForeignKey(editable=False, null=True, on_delete=django.db.models.deletion.PROTECT, related_name='+', to='sites.site')),
                ('subject_visit', models.OneToOneField(on_delete=django.db.models.deletion.PROTECT, to='mocca_subject.subjectvisit')),
            ],
            options={
                'verbose_name': 'Blood Result: Lipids',
                'verbose_name_plural': 'Blood Results: Lipids',
                'ordering': ('-modified', '-created'),
                'get_latest_by': 'modified',
                'abstract': False,
                'default_permissions': ('add', 'change', 'delete', 'view', 'export', 'import'),
            },
            managers=[
                ('objects', edc_visit_tracking.managers.CrfModelManager()),
                ('on_site', edc_visit_tracking.managers.CurrentSiteManager()),
            ],
        ),
        migrations.CreateModel(
            name='BloodResultsFbc',
            fields=[
                ('revision', django_revision.revision_field.RevisionField(blank=True, editable=False, help_text='System field. Git repository tag:branch:commit.', max_length=75, null=True, verbose_name='Revision')),
                ('created', models.DateTimeField(blank=True, default=django_audit_fields.models.audit_model_mixin.utcnow)),
                ('modified', models.DateTimeField(blank=True, default=django_audit_fields.models.audit_model_mixin.utcnow)),
                ('user_created', django_audit_fields.fields.userfield.UserField(blank=True, help_text='Updated by admin.save_model', max_length=50, verbose_name='user created')),
                ('user_modified', django_audit_fields.fields.userfield.UserField(blank=True, help_text='Updated by admin.save_model', max_length=50, verbose_name='user modified')),
                ('hostname_created', models.CharField(blank=True, default=_socket.gethostname, help_text='System field. (modified on create only)', max_length=60)),
                ('hostname_modified', django_audit_fields.fields.hostname_modification_field.HostnameModificationField(blank=True, help_text='System field. (modified on every save)', max_length=50)),
                ('device_created', models.CharField(blank=True, max_length=10)),
                ('device_modified', models.CharField(blank=True, max_length=10)),
                ('id', django_audit_fields.fields.uuid_auto_field.UUIDAutoField(blank=True, editable=False, help_text='System auto field. UUID primary key.', primary_key=True, serialize=False)),
                ('tracking_identifier', models.CharField(max_length=30, unique=True)),
                ('action_identifier', models.CharField(max_length=50, unique=True)),
                ('parent_action_identifier', models.CharField(blank=True, help_text='action identifier that links to parent reference model instance.', max_length=30, null=True)),
                ('related_action_identifier', models.CharField(blank=True, help_text='action identifier that links to related reference model instance.', max_length=30, null=True)),
                ('action_item_reason', models.TextField(editable=False, null=True)),
                ('report_datetime', models.DateTimeField(default=edc_utils.date.get_utcnow, help_text="If reporting today, use today's date/time, otherwise use the date/time this information was reported.", validators=[edc_protocol.validators.datetime_not_before_study_start, edc_model.models.validators.date.datetime_not_future], verbose_name='Report Date')),
                ('consent_model', models.CharField(editable=False, max_length=50, null=True)),
                ('consent_version', models.CharField(editable=False, max_length=10, null=True)),
                ('results_abnormal', models.CharField(choices=[('Yes', 'Yes'), ('No', 'No')], max_length=25, verbose_name='Are any of the above results abnormal?')),
                ('results_reportable', models.CharField(choices=[('Yes', 'Yes'), ('No', 'No'), ('N/A', 'Not applicable')], help_text='If YES, this value will open Adverse Event Form.', max_length=25, verbose_name='If any results are abnormal, are results within grade 3 or above?')),
                ('summary', models.TextField(blank=True, null=True)),
                ('fbc_assay_datetime', models.DateTimeField(blank=True, null=True, validators=[edc_model.models.validators.date.datetime_not_future], verbose_name='Result Report Date and Time')),
                ('haemoglobin', models.DecimalField(blank=True, decimal_places=1, max_digits=6, null=True)),
                ('haemoglobin_units', models.CharField(blank=True, choices=[('g/dL', 'g/dL')], max_length=15, null=True, verbose_name='units')),
                ('haemoglobin_abnormal', models.CharField(blank=True, choices=[('Yes', 'Yes'), ('No', 'No')], max_length=25, null=True, verbose_name='abnormal')),
                ('haemoglobin_reportable', models.CharField(blank=True, choices=[('N/A', 'Not applicable'), ('3', 'Yes, grade 3'), ('4', 'Yes, grade 4'), ('No', 'Not reportable'), ('Already reported', 'Already reported'), ('present_at_baseline', 'Present at baseline')], max_length=25, null=True, verbose_name='reportable')),
                ('hct', models.DecimalField(blank=True, decimal_places=2, max_digits=6, null=True, validators=[django.core.validators.MinValueValidator(1.0), django.core.validators.MaxValueValidator(999.0)], verbose_name='Hematocrit')),
                ('hct_units', models.CharField(blank=True, choices=[('%', '%')], max_length=15, null=True, verbose_name='units')),
                ('hct_abnormal', models.CharField(blank=True, choices=[('Yes', 'Yes'), ('No', 'No')], max_length=25, null=True, verbose_name='abnormal')),
                ('hct_reportable', models.CharField(blank=True, choices=[('N/A', 'Not applicable'), ('3', 'Yes, grade 3'), ('4', 'Yes, grade 4'), ('No', 'Not reportable'), ('Already reported', 'Already reported'), ('present_at_baseline', 'Present at baseline')], max_length=25, null=True, verbose_name='reportable')),
                ('rbc', models.DecimalField(blank=True, decimal_places=2, max_digits=6, null=True, validators=[django.core.validators.MinValueValidator(1.0), django.core.validators.MaxValueValidator(999999.0)], verbose_name='Red blood cell count')),
                ('rbc_units', models.CharField(blank=True, choices=[('10^9/L', '10^9/L'), ('cells/mm^3', 'cells/mm^3')], max_length=15, null=True, verbose_name='units')),
                ('rbc_abnormal', models.CharField(blank=True, choices=[('Yes', 'Yes'), ('No', 'No')], max_length=25, null=True, verbose_name='abnormal')),
                ('rbc_reportable', models.CharField(blank=True, choices=[('N/A', 'Not applicable'), ('3', 'Yes, grade 3'), ('4', 'Yes, grade 4'), ('No', 'Not reportable'), ('Already reported', 'Already reported'), ('present_at_baseline', 'Present at baseline')], max_length=25, null=True, verbose_name='reportable')),
                ('wbc', models.DecimalField(blank=True, decimal_places=2, max_digits=6, null=True, verbose_name='WBC')),
                ('wbc_units', models.CharField(blank=True, choices=[('10^9/L', '10^9/L'), ('cells/mm^3', 'cells/mm<sup>3</sup>')], max_length=15, null=True, verbose_name='units')),
                ('wbc_abnormal', models.CharField(blank=True, choices=[('Yes', 'Yes'), ('No', 'No')], max_length=25, null=True, verbose_name='abnormal')),
                ('wbc_reportable', models.CharField(blank=True, choices=[('N/A', 'Not applicable'), ('3', 'Yes, grade 3'), ('4', 'Yes, grade 4'), ('No', 'Not reportable'), ('Already reported', 'Already reported'), ('present_at_baseline', 'Present at baseline')], max_length=25, null=True, verbose_name='reportable')),
                ('platelets', models.IntegerField(blank=True, null=True, validators=[django.core.validators.MinValueValidator(1), django.core.validators.MaxValueValidator(9999)])),
                ('platelets_units', models.CharField(blank=True, choices=[('10^9/L', '10^9/L'), ('cells/mm^3', 'cells/mm<sup>3</sup>')], max_length=15, null=True, verbose_name='units')),
                ('platelets_abnormal', models.CharField(blank=True, choices=[('Yes', 'Yes'), ('No', 'No')], max_length=25, null=True, verbose_name='abnormal')),
                ('platelets_reportable', models.CharField(blank=True, choices=[('N/A', 'Not applicable'), ('3', 'Yes, grade 3'), ('4', 'Yes, grade 4'), ('No', 'Not reportable'), ('Already reported', 'Already reported'), ('present_at_baseline', 'Present at baseline')], max_length=25, null=True, verbose_name='reportable')),
                ('action_item', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.PROTECT, to='edc_action_item.actionitem')),
                ('fbc_requisition', models.ForeignKey(blank=True, help_text='Start typing the requisition identifier or select one from this visit', null=True, on_delete=django.db.models.deletion.PROTECT, related_name='fbc', to='mocca_subject.subjectrequisition', verbose_name='Requisition')),
                ('parent_action_item', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.PROTECT, related_name='+', to='edc_action_item.actionitem')),
                ('related_action_item', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.PROTECT, related_name='+', to='edc_action_item.actionitem')),
                ('site', models.ForeignKey(editable=False, null=True, on_delete=django.db.models.deletion.PROTECT, related_name='+', to='sites.site')),
                ('subject_visit', models.OneToOneField(on_delete=django.db.models.deletion.PROTECT, to='mocca_subject.subjectvisit')),
            ],
            options={
                'ordering': ('-modified', '-created'),
                'get_latest_by': 'modified',
                'abstract': False,
                'default_permissions': ('add', 'change', 'delete', 'view', 'export', 'import'),
            },
            managers=[
                ('objects', edc_visit_tracking.managers.CrfModelManager()),
                ('on_site', edc_visit_tracking.managers.CurrentSiteManager()),
            ],
        ),
        migrations.AddIndex(
            model_name='bloodresultslipid',
            index=models.Index(fields=['subject_visit', 'site', 'id'], name='mocca_subje_subject_f7e032_idx'),
        ),
        migrations.AddIndex(
            model_name='bloodresultsfbc',
            index=models.Index(fields=['subject_visit', 'site', 'id'], name='mocca_subje_subject_6029f5_idx'),
        ),
    ]



from django.db import models
from edc_constants.choices import YES_NO
from edc_constants.constants import NO
from edc_model import models as edc_models

from mocca_lists.models import ReasonsForTesting

from ..model_mixins import CrfModelMixin


class Investigations(CrfModelMixin, edc_models.BaseUuidModel):

    """Model not used"""

    hiv_tested = models.CharField(
        verbose_name="Was the patient tested for HIV infection?",
        max_length=15,
        choices=YES_NO,
        default=NO,
    )

    hypertension_tested = models.CharField(
        verbose_name="Was the patient tested for hypertension?",
        max_length=15,
        choices=YES_NO,
        default=NO,
    )

    diabetes_tested = models.CharField(
        verbose_name="Was the patient tested for diabetes?",
        max_length=15,
        choices=YES_NO,
        default=NO,
    )

    test_date = models.DateField(verbose_name="Date test requested", null=True, blank=True)

    reason = models.ManyToManyField(
        ReasonsForTesting, verbose_name="Why was the patient tested?", blank=True
    )

    reason_other = edc_models.OtherCharField()

    class Meta(CrfModelMixin.Meta, edc_models.BaseUuidModel.Meta):
        verbose_name = "Investigations"
        verbose_name_plural = "Investigations"
